import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DashboardTemplateVariable {
    /**
     * The list of values that the template variable drop-down is be limited to.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#available_values Dashboard#available_values}
     *
     * @stability stable
     */
    readonly availableValues?: string[];
    /**
     * The default value for the template variable on dashboard load.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#default Dashboard#default}
     *
     * @stability stable
     */
    readonly default?: string;
    /**
     * The name of the variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The tag prefix associated with the variable. Only tags with this prefix appear in the variable dropdown.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#prefix Dashboard#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
}
export declare function dashboardTemplateVariableToTerraform(struct?: DashboardTemplateVariable): any;
/**
 * @stability stable
 */
export interface DashboardTemplateVariablePresetTemplateVariable {
    /**
     * The name of the template variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The value that should be assumed by the template variable in this preset.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function dashboardTemplateVariablePresetTemplateVariableToTerraform(struct?: DashboardTemplateVariablePresetTemplateVariable): any;
/**
 * @stability stable
 */
export interface DashboardTemplateVariablePreset {
    /**
     * The name of the preset.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * template_variable block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#template_variable Dashboard#template_variable}
     *
     * @stability stable
     */
    readonly templateVariable?: DashboardTemplateVariablePresetTemplateVariable[];
}
export declare function dashboardTemplateVariablePresetToTerraform(struct?: DashboardTemplateVariablePreset): any;
/**
 * @stability stable
 */
export interface DashboardWidgetAlertGraphDefinition {
    /**
     * The ID of the monitor used by the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_id Dashboard#alert_id}
     *
     * @stability stable
     */
    readonly alertId: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * Type of visualization to use when displaying the widget. Valid values are `timeseries`, `toplist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#viz_type Dashboard#viz_type}
     *
     * @stability stable
     */
    readonly vizType: string;
}
export declare function dashboardWidgetAlertGraphDefinitionToTerraform(struct?: DashboardWidgetAlertGraphDefinitionOutputReference | DashboardWidgetAlertGraphDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetAlertGraphDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetAlertGraphDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetAlertGraphDefinition | undefined);
    private _alertId?;
    /**
     * @stability stable
     */
    get alertId(): string;
    /**
     * @stability stable
     */
    set alertId(value: string);
    /**
     * @stability stable
     */
    get alertIdInput(): string | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _vizType?;
    /**
     * @stability stable
     */
    get vizType(): string;
    /**
     * @stability stable
     */
    set vizType(value: string);
    /**
     * @stability stable
     */
    get vizTypeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetAlertValueDefinition {
    /**
     * The ID of the monitor used by the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_id Dashboard#alert_id}
     *
     * @stability stable
     */
    readonly alertId: string;
    /**
     * The precision to use when displaying the value. Use `*` for maximum precision.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#precision Dashboard#precision}
     *
     * @stability stable
     */
    readonly precision?: number;
    /**
     * The alignment of the text in the widget. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * The unit for the value displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#unit Dashboard#unit}
     *
     * @stability stable
     */
    readonly unit?: string;
}
export declare function dashboardWidgetAlertValueDefinitionToTerraform(struct?: DashboardWidgetAlertValueDefinitionOutputReference | DashboardWidgetAlertValueDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetAlertValueDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetAlertValueDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetAlertValueDefinition | undefined);
    private _alertId?;
    /**
     * @stability stable
     */
    get alertId(): string;
    /**
     * @stability stable
     */
    set alertId(value: string);
    /**
     * @stability stable
     */
    get alertIdInput(): string | undefined;
    private _precision?;
    /**
     * @stability stable
     */
    get precision(): number;
    /**
     * @stability stable
     */
    set precision(value: number);
    /**
     * @stability stable
     */
    resetPrecision(): void;
    /**
     * @stability stable
     */
    get precisionInput(): number | undefined;
    private _textAlign?;
    /**
     * @stability stable
     */
    get textAlign(): string;
    /**
     * @stability stable
     */
    set textAlign(value: string);
    /**
     * @stability stable
     */
    resetTextAlign(): void;
    /**
     * @stability stable
     */
    get textAlignInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _unit?;
    /**
     * @stability stable
     */
    get unit(): string;
    /**
     * @stability stable
     */
    set unit(value: string);
    /**
     * @stability stable
     */
    resetUnit(): void;
    /**
     * @stability stable
     */
    get unitInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
export declare function dashboardWidgetChangeDefinitionCustomLinkToTerraform(struct?: DashboardWidgetChangeDefinitionCustomLink): any;
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetChangeDefinitionRequestApmQueryComputeQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestApmQueryComputeQueryOutputReference | DashboardWidgetChangeDefinitionRequestApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetChangeDefinitionRequestApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestApmQueryGroupBySortQueryOutputReference | DashboardWidgetChangeDefinitionRequestApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetChangeDefinitionRequestApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetChangeDefinitionRequestApmQueryGroupByToTerraform(struct?: DashboardWidgetChangeDefinitionRequestApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetChangeDefinitionRequestApmQueryMultiComputeToTerraform(struct?: DashboardWidgetChangeDefinitionRequestApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetChangeDefinitionRequestApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetChangeDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetChangeDefinitionRequestApmQueryMultiCompute[];
}
export declare function dashboardWidgetChangeDefinitionRequestApmQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestApmQueryOutputReference | DashboardWidgetChangeDefinitionRequestApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetChangeDefinitionRequestApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetChangeDefinitionRequestApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetChangeDefinitionRequestApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetChangeDefinitionRequestApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetChangeDefinitionRequestApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetChangeDefinitionRequestApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetChangeDefinitionRequestApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetChangeDefinitionRequestApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetChangeDefinitionRequestApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetChangeDefinitionRequestLogQueryComputeQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestLogQueryComputeQueryOutputReference | DashboardWidgetChangeDefinitionRequestLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetChangeDefinitionRequestLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestLogQueryGroupBySortQueryOutputReference | DashboardWidgetChangeDefinitionRequestLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetChangeDefinitionRequestLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetChangeDefinitionRequestLogQueryGroupByToTerraform(struct?: DashboardWidgetChangeDefinitionRequestLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetChangeDefinitionRequestLogQueryMultiComputeToTerraform(struct?: DashboardWidgetChangeDefinitionRequestLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetChangeDefinitionRequestLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetChangeDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetChangeDefinitionRequestLogQueryMultiCompute[];
}
export declare function dashboardWidgetChangeDefinitionRequestLogQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestLogQueryOutputReference | DashboardWidgetChangeDefinitionRequestLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetChangeDefinitionRequestLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetChangeDefinitionRequestLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetChangeDefinitionRequestLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetChangeDefinitionRequestLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetChangeDefinitionRequestLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetChangeDefinitionRequestLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetChangeDefinitionRequestLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetChangeDefinitionRequestLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetChangeDefinitionRequestLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
export declare function dashboardWidgetChangeDefinitionRequestProcessQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestProcessQueryOutputReference | DashboardWidgetChangeDefinitionRequestProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestProcessQuery | undefined);
    private _filterBy?;
    /**
     * @stability stable
     */
    get filterBy(): string[];
    /**
     * @stability stable
     */
    set filterBy(value: string[]);
    /**
     * @stability stable
     */
    resetFilterBy(): void;
    /**
     * @stability stable
     */
    get filterByInput(): string[] | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _searchBy?;
    /**
     * @stability stable
     */
    get searchBy(): string;
    /**
     * @stability stable
     */
    set searchBy(value: string);
    /**
     * @stability stable
     */
    resetSearchBy(): void;
    /**
     * @stability stable
     */
    get searchByInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetChangeDefinitionRequestRumQueryComputeQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestRumQueryComputeQueryOutputReference | DashboardWidgetChangeDefinitionRequestRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetChangeDefinitionRequestRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestRumQueryGroupBySortQueryOutputReference | DashboardWidgetChangeDefinitionRequestRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetChangeDefinitionRequestRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetChangeDefinitionRequestRumQueryGroupByToTerraform(struct?: DashboardWidgetChangeDefinitionRequestRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetChangeDefinitionRequestRumQueryMultiComputeToTerraform(struct?: DashboardWidgetChangeDefinitionRequestRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetChangeDefinitionRequestRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetChangeDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetChangeDefinitionRequestRumQueryMultiCompute[];
}
export declare function dashboardWidgetChangeDefinitionRequestRumQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestRumQueryOutputReference | DashboardWidgetChangeDefinitionRequestRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetChangeDefinitionRequestRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetChangeDefinitionRequestRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetChangeDefinitionRequestRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetChangeDefinitionRequestRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetChangeDefinitionRequestRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetChangeDefinitionRequestRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetChangeDefinitionRequestRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetChangeDefinitionRequestRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetChangeDefinitionRequestRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetChangeDefinitionRequestSecurityQueryComputeQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQueryOutputReference | DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetChangeDefinitionRequestSecurityQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBySortQueryOutputReference | DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery;
}
export declare function dashboardWidgetChangeDefinitionRequestSecurityQueryGroupByToTerraform(struct?: DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetChangeDefinitionRequestSecurityQueryMultiComputeToTerraform(struct?: DashboardWidgetChangeDefinitionRequestSecurityQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetChangeDefinitionRequestSecurityQueryMultiCompute[];
}
export declare function dashboardWidgetChangeDefinitionRequestSecurityQueryToTerraform(struct?: DashboardWidgetChangeDefinitionRequestSecurityQueryOutputReference | DashboardWidgetChangeDefinitionRequestSecurityQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionRequestSecurityQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinitionRequestSecurityQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinitionRequestSecurityQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetChangeDefinitionRequestSecurityQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetChangeDefinitionRequestSecurityQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetChangeDefinitionRequestSecurityQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetChangeDefinitionRequestSecurityQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetChangeDefinitionRequestSecurityQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinitionRequest {
    /**
     * Whether to show absolute or relative change. Valid values are `absolute`, `relative`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#change_type Dashboard#change_type}
     *
     * @stability stable
     */
    readonly changeType?: string;
    /**
     * Choose from when to compare current data to. Valid values are `hour_before`, `day_before`, `week_before`, `month_before`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compare_to Dashboard#compare_to}
     *
     * @stability stable
     */
    readonly compareTo?: string;
    /**
     * A Boolean indicating whether an increase in the value is good (displayed in green) or not (displayed in red).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#increase_good Dashboard#increase_good}
     *
     * @stability stable
     */
    readonly increaseGood?: boolean | cdktf.IResolvable;
    /**
     * What to order by. Valid values are `change`, `name`, `present`, `past`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order_by Dashboard#order_by}
     *
     * @stability stable
     */
    readonly orderBy?: string;
    /**
     * Widget sorting method. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order_dir Dashboard#order_dir}
     *
     * @stability stable
     */
    readonly orderDir?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * If set to `true`, displays the current value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_present Dashboard#show_present}
     *
     * @stability stable
     */
    readonly showPresent?: boolean | cdktf.IResolvable;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetChangeDefinitionRequestApmQuery;
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetChangeDefinitionRequestLogQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetChangeDefinitionRequestProcessQuery;
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetChangeDefinitionRequestRumQuery;
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetChangeDefinitionRequestSecurityQuery;
}
export declare function dashboardWidgetChangeDefinitionRequestToTerraform(struct?: DashboardWidgetChangeDefinitionRequest): any;
/**
 * @stability stable
 */
export interface DashboardWidgetChangeDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetChangeDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetChangeDefinitionRequest[];
}
export declare function dashboardWidgetChangeDefinitionToTerraform(struct?: DashboardWidgetChangeDefinitionOutputReference | DashboardWidgetChangeDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetChangeDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetChangeDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetChangeDefinition | undefined);
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _customLink?;
    /**
     * @stability stable
     */
    get customLink(): DashboardWidgetChangeDefinitionCustomLink[];
    /**
     * @stability stable
     */
    set customLink(value: DashboardWidgetChangeDefinitionCustomLink[]);
    /**
     * @stability stable
     */
    resetCustomLink(): void;
    /**
     * @stability stable
     */
    get customLinkInput(): DashboardWidgetChangeDefinitionCustomLink[] | undefined;
    private _request?;
    /**
     * @stability stable
     */
    get request(): DashboardWidgetChangeDefinitionRequest[];
    /**
     * @stability stable
     */
    set request(value: DashboardWidgetChangeDefinitionRequest[]);
    /**
     * @stability stable
     */
    resetRequest(): void;
    /**
     * @stability stable
     */
    get requestInput(): DashboardWidgetChangeDefinitionRequest[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetCheckStatusDefinition {
    /**
     * The check to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#check Dashboard#check}
     *
     * @stability stable
     */
    readonly check: string;
    /**
     * The check group to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group Dashboard#group}
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * When `grouping = "cluster"`, indicates a list of tags to use for grouping.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: string[];
    /**
     * The kind of grouping to use. Valid values are `check`, `cluster`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#grouping Dashboard#grouping}
     *
     * @stability stable
     */
    readonly grouping: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * A list of tags to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags Dashboard#tags}
     *
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
export declare function dashboardWidgetCheckStatusDefinitionToTerraform(struct?: DashboardWidgetCheckStatusDefinitionOutputReference | DashboardWidgetCheckStatusDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetCheckStatusDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetCheckStatusDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetCheckStatusDefinition | undefined);
    private _check?;
    /**
     * @stability stable
     */
    get check(): string;
    /**
     * @stability stable
     */
    set check(value: string);
    /**
     * @stability stable
     */
    get checkInput(): string | undefined;
    private _group?;
    /**
     * @stability stable
     */
    get group(): string;
    /**
     * @stability stable
     */
    set group(value: string);
    /**
     * @stability stable
     */
    resetGroup(): void;
    /**
     * @stability stable
     */
    get groupInput(): string | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): string[];
    /**
     * @stability stable
     */
    set groupBy(value: string[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): string[] | undefined;
    private _grouping?;
    /**
     * @stability stable
     */
    get grouping(): string;
    /**
     * @stability stable
     */
    set grouping(value: string);
    /**
     * @stability stable
     */
    get groupingInput(): string | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): string[];
    /**
     * @stability stable
     */
    set tags(value: string[]);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): string[] | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetDistributionDefinitionRequestApmQueryComputeQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestApmQueryComputeQueryOutputReference | DashboardWidgetDistributionDefinitionRequestApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetDistributionDefinitionRequestApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestApmQueryGroupBySortQueryOutputReference | DashboardWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetDistributionDefinitionRequestApmQueryGroupByToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetDistributionDefinitionRequestApmQueryMultiComputeToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetDistributionDefinitionRequestApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetDistributionDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetDistributionDefinitionRequestApmQueryMultiCompute[];
}
export declare function dashboardWidgetDistributionDefinitionRequestApmQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestApmQueryOutputReference | DashboardWidgetDistributionDefinitionRequestApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetDistributionDefinitionRequestApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetDistributionDefinitionRequestApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetDistributionDefinitionRequestApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetDistributionDefinitionRequestApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetDistributionDefinitionRequestApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetDistributionDefinitionRequestApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetDistributionDefinitionRequestApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetDistributionDefinitionRequestApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetDistributionDefinitionRequestApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetDistributionDefinitionRequestLogQueryComputeQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestLogQueryComputeQueryOutputReference | DashboardWidgetDistributionDefinitionRequestLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetDistributionDefinitionRequestLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestLogQueryGroupBySortQueryOutputReference | DashboardWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetDistributionDefinitionRequestLogQueryGroupByToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetDistributionDefinitionRequestLogQueryMultiComputeToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetDistributionDefinitionRequestLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetDistributionDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetDistributionDefinitionRequestLogQueryMultiCompute[];
}
export declare function dashboardWidgetDistributionDefinitionRequestLogQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestLogQueryOutputReference | DashboardWidgetDistributionDefinitionRequestLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetDistributionDefinitionRequestLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetDistributionDefinitionRequestLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetDistributionDefinitionRequestLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetDistributionDefinitionRequestLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetDistributionDefinitionRequestLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetDistributionDefinitionRequestLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetDistributionDefinitionRequestLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetDistributionDefinitionRequestLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetDistributionDefinitionRequestLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
export declare function dashboardWidgetDistributionDefinitionRequestProcessQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestProcessQueryOutputReference | DashboardWidgetDistributionDefinitionRequestProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestProcessQuery | undefined);
    private _filterBy?;
    /**
     * @stability stable
     */
    get filterBy(): string[];
    /**
     * @stability stable
     */
    set filterBy(value: string[]);
    /**
     * @stability stable
     */
    resetFilterBy(): void;
    /**
     * @stability stable
     */
    get filterByInput(): string[] | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _searchBy?;
    /**
     * @stability stable
     */
    get searchBy(): string;
    /**
     * @stability stable
     */
    set searchBy(value: string);
    /**
     * @stability stable
     */
    resetSearchBy(): void;
    /**
     * @stability stable
     */
    get searchByInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetDistributionDefinitionRequestRumQueryComputeQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestRumQueryComputeQueryOutputReference | DashboardWidgetDistributionDefinitionRequestRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetDistributionDefinitionRequestRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestRumQueryGroupBySortQueryOutputReference | DashboardWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetDistributionDefinitionRequestRumQueryGroupByToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetDistributionDefinitionRequestRumQueryMultiComputeToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetDistributionDefinitionRequestRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetDistributionDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetDistributionDefinitionRequestRumQueryMultiCompute[];
}
export declare function dashboardWidgetDistributionDefinitionRequestRumQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestRumQueryOutputReference | DashboardWidgetDistributionDefinitionRequestRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetDistributionDefinitionRequestRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetDistributionDefinitionRequestRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetDistributionDefinitionRequestRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetDistributionDefinitionRequestRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetDistributionDefinitionRequestRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetDistributionDefinitionRequestRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetDistributionDefinitionRequestRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetDistributionDefinitionRequestRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetDistributionDefinitionRequestRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQueryOutputReference | DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQueryOutputReference | DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery;
}
export declare function dashboardWidgetDistributionDefinitionRequestSecurityQueryGroupByToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetDistributionDefinitionRequestSecurityQueryMultiComputeToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestSecurityQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetDistributionDefinitionRequestSecurityQueryMultiCompute[];
}
export declare function dashboardWidgetDistributionDefinitionRequestSecurityQueryToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestSecurityQueryOutputReference | DashboardWidgetDistributionDefinitionRequestSecurityQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestSecurityQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestSecurityQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestSecurityQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetDistributionDefinitionRequestSecurityQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetDistributionDefinitionRequestSecurityQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetDistributionDefinitionRequestSecurityQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetDistributionDefinitionRequestSecurityQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetDistributionDefinitionRequestSecurityQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequestStyle {
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
}
export declare function dashboardWidgetDistributionDefinitionRequestStyleToTerraform(struct?: DashboardWidgetDistributionDefinitionRequestStyleOutputReference | DashboardWidgetDistributionDefinitionRequestStyle): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionRequestStyleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinitionRequestStyle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinitionRequestStyle | undefined);
    private _palette?;
    /**
     * @stability stable
     */
    get palette(): string;
    /**
     * @stability stable
     */
    set palette(value: string);
    /**
     * @stability stable
     */
    resetPalette(): void;
    /**
     * @stability stable
     */
    get paletteInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetDistributionDefinitionRequestApmQuery;
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetDistributionDefinitionRequestLogQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetDistributionDefinitionRequestProcessQuery;
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetDistributionDefinitionRequestRumQuery;
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetDistributionDefinitionRequestSecurityQuery;
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetDistributionDefinitionRequestStyle;
}
export declare function dashboardWidgetDistributionDefinitionRequestToTerraform(struct?: DashboardWidgetDistributionDefinitionRequest): any;
/**
 * @stability stable
 */
export interface DashboardWidgetDistributionDefinition {
    /**
     * The size of the legend displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_size Dashboard#legend_size}
     *
     * @stability stable
     */
    readonly legendSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * Whether or not to show the legend on this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_legend Dashboard#show_legend}
     *
     * @stability stable
     */
    readonly showLegend?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetDistributionDefinitionRequest[];
}
export declare function dashboardWidgetDistributionDefinitionToTerraform(struct?: DashboardWidgetDistributionDefinitionOutputReference | DashboardWidgetDistributionDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetDistributionDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetDistributionDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetDistributionDefinition | undefined);
    private _legendSize?;
    /**
     * @stability stable
     */
    get legendSize(): string;
    /**
     * @stability stable
     */
    set legendSize(value: string);
    /**
     * @stability stable
     */
    resetLegendSize(): void;
    /**
     * @stability stable
     */
    get legendSizeInput(): string | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _showLegend?;
    /**
     * @stability stable
     */
    get showLegend(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set showLegend(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShowLegend(): void;
    /**
     * @stability stable
     */
    get showLegendInput(): boolean | cdktf.IResolvable | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _request?;
    /**
     * @stability stable
     */
    get request(): DashboardWidgetDistributionDefinitionRequest[];
    /**
     * @stability stable
     */
    set request(value: DashboardWidgetDistributionDefinitionRequest[]);
    /**
     * @stability stable
     */
    resetRequest(): void;
    /**
     * @stability stable
     */
    get requestInput(): DashboardWidgetDistributionDefinitionRequest[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetEventStreamDefinition {
    /**
     * The size to use to display an event. Valid values are `s`, `l`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_size Dashboard#event_size}
     *
     * @stability stable
     */
    readonly eventSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * The execution method for multi-value filters, options: `and` or `or`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
export declare function dashboardWidgetEventStreamDefinitionToTerraform(struct?: DashboardWidgetEventStreamDefinitionOutputReference | DashboardWidgetEventStreamDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetEventStreamDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetEventStreamDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetEventStreamDefinition | undefined);
    private _eventSize?;
    /**
     * @stability stable
     */
    get eventSize(): string;
    /**
     * @stability stable
     */
    set eventSize(value: string);
    /**
     * @stability stable
     */
    resetEventSize(): void;
    /**
     * @stability stable
     */
    get eventSizeInput(): string | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
    private _tagsExecution?;
    /**
     * @stability stable
     */
    get tagsExecution(): string;
    /**
     * @stability stable
     */
    set tagsExecution(value: string);
    /**
     * @stability stable
     */
    resetTagsExecution(): void;
    /**
     * @stability stable
     */
    get tagsExecutionInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetEventTimelineDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * The execution method for multi-value filters, options: `and` or `or`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
export declare function dashboardWidgetEventTimelineDefinitionToTerraform(struct?: DashboardWidgetEventTimelineDefinitionOutputReference | DashboardWidgetEventTimelineDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetEventTimelineDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetEventTimelineDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetEventTimelineDefinition | undefined);
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
    private _tagsExecution?;
    /**
     * @stability stable
     */
    get tagsExecution(): string;
    /**
     * @stability stable
     */
    set tagsExecution(value: string);
    /**
     * @stability stable
     */
    resetTagsExecution(): void;
    /**
     * @stability stable
     */
    get tagsExecutionInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetFreeTextDefinition {
    /**
     * The color of the text in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#color Dashboard#color}
     *
     * @stability stable
     */
    readonly color?: string;
    /**
     * The size of the text in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#font_size Dashboard#font_size}
     *
     * @stability stable
     */
    readonly fontSize?: string;
    /**
     * The text to display in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text Dashboard#text}
     *
     * @stability stable
     */
    readonly text: string;
    /**
     * The alignment of the text in the widget. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
}
export declare function dashboardWidgetFreeTextDefinitionToTerraform(struct?: DashboardWidgetFreeTextDefinitionOutputReference | DashboardWidgetFreeTextDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetFreeTextDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetFreeTextDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetFreeTextDefinition | undefined);
    private _color?;
    /**
     * @stability stable
     */
    get color(): string;
    /**
     * @stability stable
     */
    set color(value: string);
    /**
     * @stability stable
     */
    resetColor(): void;
    /**
     * @stability stable
     */
    get colorInput(): string | undefined;
    private _fontSize?;
    /**
     * @stability stable
     */
    get fontSize(): string;
    /**
     * @stability stable
     */
    set fontSize(value: string);
    /**
     * @stability stable
     */
    resetFontSize(): void;
    /**
     * @stability stable
     */
    get fontSizeInput(): string | undefined;
    private _text?;
    /**
     * @stability stable
     */
    get text(): string;
    /**
     * @stability stable
     */
    set text(value: string);
    /**
     * @stability stable
     */
    get textInput(): string | undefined;
    private _textAlign?;
    /**
     * @stability stable
     */
    get textAlign(): string;
    /**
     * @stability stable
     */
    set textAlign(value: string);
    /**
     * @stability stable
     */
    resetTextAlign(): void;
    /**
     * @stability stable
     */
    get textAlignInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
export declare function dashboardWidgetGeomapDefinitionCustomLinkToTerraform(struct?: DashboardWidgetGeomapDefinitionCustomLink): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function dashboardWidgetGeomapDefinitionRequestFormulaConditionalFormatsToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestFormulaConditionalFormats): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
export declare function dashboardWidgetGeomapDefinitionRequestFormulaLimitToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestFormulaLimitOutputReference | DashboardWidgetGeomapDefinitionRequestFormulaLimit): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestFormulaLimitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestFormulaLimit | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestFormulaLimit | undefined);
    private _count?;
    /**
     * @stability stable
     */
    get count(): number;
    /**
     * @stability stable
     */
    set count(value: number);
    /**
     * @stability stable
     */
    resetCount(): void;
    /**
     * @stability stable
     */
    get countInput(): number | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    resetOrder(): void;
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGeomapDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetGeomapDefinitionRequestFormulaLimit;
}
export declare function dashboardWidgetGeomapDefinitionRequestFormulaToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestFormula): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGeomapDefinitionRequestLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestLogQueryComputeQueryOutputReference | DashboardWidgetGeomapDefinitionRequestLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGeomapDefinitionRequestLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestLogQueryGroupBySortQueryOutputReference | DashboardWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetGeomapDefinitionRequestLogQueryGroupByToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGeomapDefinitionRequestLogQueryMultiComputeToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGeomapDefinitionRequestLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGeomapDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGeomapDefinitionRequestLogQueryMultiCompute[];
}
export declare function dashboardWidgetGeomapDefinitionRequestLogQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestLogQueryOutputReference | DashboardWidgetGeomapDefinitionRequestLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGeomapDefinitionRequestLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGeomapDefinitionRequestLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGeomapDefinitionRequestLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGeomapDefinitionRequestLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGeomapDefinitionRequestLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGeomapDefinitionRequestLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGeomapDefinitionRequestLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGeomapDefinitionRequestLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGeomapDefinitionRequestLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery {
    /**
     * The data source for APM Dependency Stats queries. Valid values are `apm_dependency_stats`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * APM Environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * Determines whether stats for upstream or downstream dependencies should be queried.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_upstream Dashboard#is_upstream}
     *
     * @stability stable
     */
    readonly isUpstream?: boolean | cdktf.IResolvable;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Name of operation on service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#operation_name Dashboard#operation_name}
     *
     * @stability stable
     */
    readonly operationName: string;
    /**
     * The name of the second primary tag used within APM; required when `primary_tag_value` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_name Dashboard#primary_tag_name}
     *
     * @stability stable
     */
    readonly primaryTagName?: string;
    /**
     * Filter APM data by the second primary tag. `primary_tag_name` must also be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_value Dashboard#primary_tag_value}
     *
     * @stability stable
     */
    readonly primaryTagValue?: string;
    /**
     * APM resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#resource_name Dashboard#resource_name}
     *
     * @stability stable
     */
    readonly resourceName: string;
    /**
     * APM service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * APM statistic. Valid values are `avg_duration`, `avg_root_duration`, `avg_spans_per_trace`, `error_rate`, `pct_exec_time`, `pct_of_traces`, `total_traces_count`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#stat Dashboard#stat}
     *
     * @stability stable
     */
    readonly stat: string;
}
export declare function dashboardWidgetGeomapDefinitionRequestQueryApmDependencyStatsQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestQueryApmDependencyStatsQueryOutputReference | DashboardWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestQueryApmDependencyStatsQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _env?;
    /**
     * @stability stable
     */
    get env(): string;
    /**
     * @stability stable
     */
    set env(value: string);
    /**
     * @stability stable
     */
    get envInput(): string | undefined;
    private _isUpstream?;
    /**
     * @stability stable
     */
    get isUpstream(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isUpstream(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsUpstream(): void;
    /**
     * @stability stable
     */
    get isUpstreamInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _operationName?;
    /**
     * @stability stable
     */
    get operationName(): string;
    /**
     * @stability stable
     */
    set operationName(value: string);
    /**
     * @stability stable
     */
    get operationNameInput(): string | undefined;
    private _primaryTagName?;
    /**
     * @stability stable
     */
    get primaryTagName(): string;
    /**
     * @stability stable
     */
    set primaryTagName(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagName(): void;
    /**
     * @stability stable
     */
    get primaryTagNameInput(): string | undefined;
    private _primaryTagValue?;
    /**
     * @stability stable
     */
    get primaryTagValue(): string;
    /**
     * @stability stable
     */
    set primaryTagValue(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagValue(): void;
    /**
     * @stability stable
     */
    get primaryTagValueInput(): string | undefined;
    private _resourceName?;
    /**
     * @stability stable
     */
    get resourceName(): string;
    /**
     * @stability stable
     */
    set resourceName(value: string);
    /**
     * @stability stable
     */
    get resourceNameInput(): string | undefined;
    private _service?;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string | undefined;
    private _stat?;
    /**
     * @stability stable
     */
    get stat(): string;
    /**
     * @stability stable
     */
    set stat(value: string);
    /**
     * @stability stable
     */
    get statInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery {
    /**
     * The data source for APM Resource Stats queries. Valid values are `apm_resource_stats`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * APM Environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * Array of fields to group results by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Name of operation on service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#operation_name Dashboard#operation_name}
     *
     * @stability stable
     */
    readonly operationName?: string;
    /**
     * The name of the second primary tag used within APM; required when `primary_tag_value` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_name Dashboard#primary_tag_name}
     *
     * @stability stable
     */
    readonly primaryTagName?: string;
    /**
     * Filter APM data by the second primary tag. `primary_tag_name` must also be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_value Dashboard#primary_tag_value}
     *
     * @stability stable
     */
    readonly primaryTagValue?: string;
    /**
     * APM resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#resource_name Dashboard#resource_name}
     *
     * @stability stable
     */
    readonly resourceName?: string;
    /**
     * APM service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * APM statistic. Valid values are `errors`, `error_rate`, `hits`, `latency_avg`, `latency_max`, `latency_p50`, `latency_p75`, `latency_p90`, `latency_p95`, `latency_p99`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#stat Dashboard#stat}
     *
     * @stability stable
     */
    readonly stat: string;
}
export declare function dashboardWidgetGeomapDefinitionRequestQueryApmResourceStatsQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestQueryApmResourceStatsQueryOutputReference | DashboardWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestQueryApmResourceStatsQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _env?;
    /**
     * @stability stable
     */
    get env(): string;
    /**
     * @stability stable
     */
    set env(value: string);
    /**
     * @stability stable
     */
    get envInput(): string | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): string[];
    /**
     * @stability stable
     */
    set groupBy(value: string[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _operationName?;
    /**
     * @stability stable
     */
    get operationName(): string;
    /**
     * @stability stable
     */
    set operationName(value: string);
    /**
     * @stability stable
     */
    resetOperationName(): void;
    /**
     * @stability stable
     */
    get operationNameInput(): string | undefined;
    private _primaryTagName?;
    /**
     * @stability stable
     */
    get primaryTagName(): string;
    /**
     * @stability stable
     */
    set primaryTagName(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagName(): void;
    /**
     * @stability stable
     */
    get primaryTagNameInput(): string | undefined;
    private _primaryTagValue?;
    /**
     * @stability stable
     */
    get primaryTagValue(): string;
    /**
     * @stability stable
     */
    set primaryTagValue(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagValue(): void;
    /**
     * @stability stable
     */
    get primaryTagValueInput(): string | undefined;
    private _resourceName?;
    /**
     * @stability stable
     */
    get resourceName(): string;
    /**
     * @stability stable
     */
    set resourceName(value: string);
    /**
     * @stability stable
     */
    resetResourceName(): void;
    /**
     * @stability stable
     */
    get resourceNameInput(): string | undefined;
    private _service?;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string | undefined;
    private _stat?;
    /**
     * @stability stable
     */
    get stat(): string;
    /**
     * @stability stable
     */
    set stat(value: string);
    /**
     * @stability stable
     */
    get statInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
export declare function dashboardWidgetGeomapDefinitionRequestQueryEventQueryComputeToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestQueryEventQueryCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
export declare function dashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBySortToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBySortOutputReference | DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBySortOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    resetMetric(): void;
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    resetOrder(): void;
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort;
}
export declare function dashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupByToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function dashboardWidgetGeomapDefinitionRequestQueryEventQuerySearchToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearchOutputReference | DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearch): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearch | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearch | undefined);
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetGeomapDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearch;
}
export declare function dashboardWidgetGeomapDefinitionRequestQueryEventQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestQueryEventQueryOutputReference | DashboardWidgetGeomapDefinitionRequestQueryEventQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestQueryEventQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestQueryEventQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestQueryEventQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _indexes?;
    /**
     * @stability stable
     */
    get indexes(): string[];
    /**
     * @stability stable
     */
    set indexes(value: string[]);
    /**
     * @stability stable
     */
    resetIndexes(): void;
    /**
     * @stability stable
     */
    get indexesInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _compute?;
    /**
     * @stability stable
     */
    get compute(): DashboardWidgetGeomapDefinitionRequestQueryEventQueryCompute[];
    /**
     * @stability stable
     */
    set compute(value: DashboardWidgetGeomapDefinitionRequestQueryEventQueryCompute[]);
    /**
     * @stability stable
     */
    get computeInput(): DashboardWidgetGeomapDefinitionRequestQueryEventQueryCompute[] | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGeomapDefinitionRequestQueryEventQueryGroupBy[] | undefined;
    private _search;
    /**
     * @stability stable
     */
    get search(): DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearchOutputReference;
    /**
     * @stability stable
     */
    putSearch(value: DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearch): void;
    /**
     * @stability stable
     */
    resetSearch(): void;
    /**
     * @stability stable
     */
    get searchInput(): DashboardWidgetGeomapDefinitionRequestQueryEventQuerySearch | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function dashboardWidgetGeomapDefinitionRequestQueryMetricQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestQueryMetricQueryOutputReference | DashboardWidgetGeomapDefinitionRequestQueryMetricQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestQueryMetricQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestQueryMetricQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestQueryMetricQuery | undefined);
    private _aggregator?;
    /**
     * @stability stable
     */
    get aggregator(): string;
    /**
     * @stability stable
     */
    set aggregator(value: string);
    /**
     * @stability stable
     */
    resetAggregator(): void;
    /**
     * @stability stable
     */
    get aggregatorInput(): string | undefined;
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    resetDataSource(): void;
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
export declare function dashboardWidgetGeomapDefinitionRequestQueryProcessQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestQueryProcessQueryOutputReference | DashboardWidgetGeomapDefinitionRequestQueryProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestQueryProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestQueryProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestQueryProcessQuery | undefined);
    private _aggregator?;
    /**
     * @stability stable
     */
    get aggregator(): string;
    /**
     * @stability stable
     */
    set aggregator(value: string);
    /**
     * @stability stable
     */
    resetAggregator(): void;
    /**
     * @stability stable
     */
    get aggregatorInput(): string | undefined;
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _isNormalizedCpu?;
    /**
     * @stability stable
     */
    get isNormalizedCpu(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isNormalizedCpu(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsNormalizedCpu(): void;
    /**
     * @stability stable
     */
    get isNormalizedCpuInput(): boolean | cdktf.IResolvable | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _sort?;
    /**
     * @stability stable
     */
    get sort(): string;
    /**
     * @stability stable
     */
    set sort(value: string);
    /**
     * @stability stable
     */
    resetSort(): void;
    /**
     * @stability stable
     */
    get sortInput(): string | undefined;
    private _tagFilters?;
    /**
     * @stability stable
     */
    get tagFilters(): string[];
    /**
     * @stability stable
     */
    set tagFilters(value: string[]);
    /**
     * @stability stable
     */
    resetTagFilters(): void;
    /**
     * @stability stable
     */
    get tagFiltersInput(): string[] | undefined;
    private _textFilter?;
    /**
     * @stability stable
     */
    get textFilter(): string;
    /**
     * @stability stable
     */
    set textFilter(value: string);
    /**
     * @stability stable
     */
    resetTextFilter(): void;
    /**
     * @stability stable
     */
    get textFilterInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestQuery {
    /**
     * apm_dependency_stats_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_dependency_stats_query Dashboard#apm_dependency_stats_query}
     *
     * @stability stable
     */
    readonly apmDependencyStatsQuery?: DashboardWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery;
    /**
     * apm_resource_stats_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_resource_stats_query Dashboard#apm_resource_stats_query}
     *
     * @stability stable
     */
    readonly apmResourceStatsQuery?: DashboardWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery;
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetGeomapDefinitionRequestQueryEventQuery;
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetGeomapDefinitionRequestQueryMetricQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGeomapDefinitionRequestQueryProcessQuery;
}
export declare function dashboardWidgetGeomapDefinitionRequestQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestQuery): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGeomapDefinitionRequestRumQueryComputeQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestRumQueryComputeQueryOutputReference | DashboardWidgetGeomapDefinitionRequestRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGeomapDefinitionRequestRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestRumQueryGroupBySortQueryOutputReference | DashboardWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetGeomapDefinitionRequestRumQueryGroupByToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGeomapDefinitionRequestRumQueryMultiComputeToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGeomapDefinitionRequestRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGeomapDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGeomapDefinitionRequestRumQueryMultiCompute[];
}
export declare function dashboardWidgetGeomapDefinitionRequestRumQueryToTerraform(struct?: DashboardWidgetGeomapDefinitionRequestRumQueryOutputReference | DashboardWidgetGeomapDefinitionRequestRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionRequestRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionRequestRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionRequestRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGeomapDefinitionRequestRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGeomapDefinitionRequestRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGeomapDefinitionRequestRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGeomapDefinitionRequestRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGeomapDefinitionRequestRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGeomapDefinitionRequestRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGeomapDefinitionRequestRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGeomapDefinitionRequestRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGeomapDefinitionRequestRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetGeomapDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGeomapDefinitionRequestLogQuery;
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetGeomapDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGeomapDefinitionRequestRumQuery;
}
export declare function dashboardWidgetGeomapDefinitionRequestToTerraform(struct?: DashboardWidgetGeomapDefinitionRequest): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionStyle {
    /**
     * The color palette to apply to the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * A Boolean indicating whether to flip the palette tones.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette_flip Dashboard#palette_flip}
     *
     * @stability stable
     */
    readonly paletteFlip: boolean | cdktf.IResolvable;
}
export declare function dashboardWidgetGeomapDefinitionStyleToTerraform(struct?: DashboardWidgetGeomapDefinitionStyleOutputReference | DashboardWidgetGeomapDefinitionStyle): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionStyleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionStyle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionStyle | undefined);
    private _palette?;
    /**
     * @stability stable
     */
    get palette(): string;
    /**
     * @stability stable
     */
    set palette(value: string);
    /**
     * @stability stable
     */
    get paletteInput(): string | undefined;
    private _paletteFlip?;
    /**
     * @stability stable
     */
    get paletteFlip(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set paletteFlip(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get paletteFlipInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinitionView {
    /**
     * The two-letter ISO code of a country to focus the map on (or `WORLD`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#focus Dashboard#focus}
     *
     * @stability stable
     */
    readonly focus: string;
}
export declare function dashboardWidgetGeomapDefinitionViewToTerraform(struct?: DashboardWidgetGeomapDefinitionViewOutputReference | DashboardWidgetGeomapDefinitionView): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionViewOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinitionView | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinitionView | undefined);
    private _focus?;
    /**
     * @stability stable
     */
    get focus(): string;
    /**
     * @stability stable
     */
    set focus(value: string);
    /**
     * @stability stable
     */
    get focusInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGeomapDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGeomapDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGeomapDefinitionRequest[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGeomapDefinitionStyle;
    /**
     * view block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#view Dashboard#view}
     *
     * @stability stable
     */
    readonly view: DashboardWidgetGeomapDefinitionView;
}
export declare function dashboardWidgetGeomapDefinitionToTerraform(struct?: DashboardWidgetGeomapDefinitionOutputReference | DashboardWidgetGeomapDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGeomapDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGeomapDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGeomapDefinition | undefined);
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _customLink?;
    /**
     * @stability stable
     */
    get customLink(): DashboardWidgetGeomapDefinitionCustomLink[];
    /**
     * @stability stable
     */
    set customLink(value: DashboardWidgetGeomapDefinitionCustomLink[]);
    /**
     * @stability stable
     */
    resetCustomLink(): void;
    /**
     * @stability stable
     */
    get customLinkInput(): DashboardWidgetGeomapDefinitionCustomLink[] | undefined;
    private _request?;
    /**
     * @stability stable
     */
    get request(): DashboardWidgetGeomapDefinitionRequest[];
    /**
     * @stability stable
     */
    set request(value: DashboardWidgetGeomapDefinitionRequest[]);
    /**
     * @stability stable
     */
    resetRequest(): void;
    /**
     * @stability stable
     */
    get requestInput(): DashboardWidgetGeomapDefinitionRequest[] | undefined;
    private _style;
    /**
     * @stability stable
     */
    get style(): DashboardWidgetGeomapDefinitionStyleOutputReference;
    /**
     * @stability stable
     */
    putStyle(value: DashboardWidgetGeomapDefinitionStyle): void;
    /**
     * @stability stable
     */
    resetStyle(): void;
    /**
     * @stability stable
     */
    get styleInput(): DashboardWidgetGeomapDefinitionStyle | undefined;
    private _view;
    /**
     * @stability stable
     */
    get view(): DashboardWidgetGeomapDefinitionViewOutputReference;
    /**
     * @stability stable
     */
    putView(value: DashboardWidgetGeomapDefinitionView): void;
    /**
     * @stability stable
     */
    get viewInput(): DashboardWidgetGeomapDefinitionView | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetAlertGraphDefinition {
    /**
     * The ID of the monitor used by the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_id Dashboard#alert_id}
     *
     * @stability stable
     */
    readonly alertId: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * Type of visualization to use when displaying the widget. Valid values are `timeseries`, `toplist`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#viz_type Dashboard#viz_type}
     *
     * @stability stable
     */
    readonly vizType: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetAlertGraphDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetAlertGraphDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetAlertGraphDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetAlertGraphDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetAlertGraphDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetAlertGraphDefinition | undefined);
    private _alertId?;
    /**
     * @stability stable
     */
    get alertId(): string;
    /**
     * @stability stable
     */
    set alertId(value: string);
    /**
     * @stability stable
     */
    get alertIdInput(): string | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _vizType?;
    /**
     * @stability stable
     */
    get vizType(): string;
    /**
     * @stability stable
     */
    set vizType(value: string);
    /**
     * @stability stable
     */
    get vizTypeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetAlertValueDefinition {
    /**
     * The ID of the monitor used by the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alert_id Dashboard#alert_id}
     *
     * @stability stable
     */
    readonly alertId: string;
    /**
     * The precision to use when displaying the value. Use `*` for maximum precision.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#precision Dashboard#precision}
     *
     * @stability stable
     */
    readonly precision?: number;
    /**
     * The alignment of the text in the widget. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * The unit for the value displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#unit Dashboard#unit}
     *
     * @stability stable
     */
    readonly unit?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetAlertValueDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetAlertValueDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetAlertValueDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetAlertValueDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetAlertValueDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetAlertValueDefinition | undefined);
    private _alertId?;
    /**
     * @stability stable
     */
    get alertId(): string;
    /**
     * @stability stable
     */
    set alertId(value: string);
    /**
     * @stability stable
     */
    get alertIdInput(): string | undefined;
    private _precision?;
    /**
     * @stability stable
     */
    get precision(): number;
    /**
     * @stability stable
     */
    set precision(value: number);
    /**
     * @stability stable
     */
    resetPrecision(): void;
    /**
     * @stability stable
     */
    get precisionInput(): number | undefined;
    private _textAlign?;
    /**
     * @stability stable
     */
    get textAlign(): string;
    /**
     * @stability stable
     */
    set textAlign(value: string);
    /**
     * @stability stable
     */
    resetTextAlign(): void;
    /**
     * @stability stable
     */
    get textAlignInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _unit?;
    /**
     * @stability stable
     */
    get unit(): string;
    /**
     * @stability stable
     */
    set unit(value: string);
    /**
     * @stability stable
     */
    resetUnit(): void;
    /**
     * @stability stable
     */
    get unitInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionCustomLinkToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionCustomLink): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestProcessQuery | undefined);
    private _filterBy?;
    /**
     * @stability stable
     */
    get filterBy(): string[];
    /**
     * @stability stable
     */
    set filterBy(value: string[]);
    /**
     * @stability stable
     */
    resetFilterBy(): void;
    /**
     * @stability stable
     */
    get filterByInput(): string[] | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _searchBy?;
    /**
     * @stability stable
     */
    get searchBy(): string;
    /**
     * @stability stable
     */
    set searchBy(value: string);
    /**
     * @stability stable
     */
    resetSearchBy(): void;
    /**
     * @stability stable
     */
    get searchByInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequest {
    /**
     * Whether to show absolute or relative change. Valid values are `absolute`, `relative`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#change_type Dashboard#change_type}
     *
     * @stability stable
     */
    readonly changeType?: string;
    /**
     * Choose from when to compare current data to. Valid values are `hour_before`, `day_before`, `week_before`, `month_before`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compare_to Dashboard#compare_to}
     *
     * @stability stable
     */
    readonly compareTo?: string;
    /**
     * A Boolean indicating whether an increase in the value is good (displayed in green) or not (displayed in red).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#increase_good Dashboard#increase_good}
     *
     * @stability stable
     */
    readonly increaseGood?: boolean | cdktf.IResolvable;
    /**
     * What to order by. Valid values are `change`, `name`, `present`, `past`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order_by Dashboard#order_by}
     *
     * @stability stable
     */
    readonly orderBy?: string;
    /**
     * Widget sorting method. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order_dir Dashboard#order_dir}
     *
     * @stability stable
     */
    readonly orderDir?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * If set to `true`, displays the current value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_present Dashboard#show_present}
     *
     * @stability stable
     */
    readonly showPresent?: boolean | cdktf.IResolvable;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestApmQuery;
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestLogQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestProcessQuery;
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestRumQuery;
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestSecurityQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionRequestToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequest): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetChangeDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequest[];
}
export declare function dashboardWidgetGroupDefinitionWidgetChangeDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetChangeDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetChangeDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetChangeDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetChangeDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetChangeDefinition | undefined);
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _customLink?;
    /**
     * @stability stable
     */
    get customLink(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionCustomLink[];
    /**
     * @stability stable
     */
    set customLink(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionCustomLink[]);
    /**
     * @stability stable
     */
    resetCustomLink(): void;
    /**
     * @stability stable
     */
    get customLinkInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionCustomLink[] | undefined;
    private _request?;
    /**
     * @stability stable
     */
    get request(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequest[];
    /**
     * @stability stable
     */
    set request(value: DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequest[]);
    /**
     * @stability stable
     */
    resetRequest(): void;
    /**
     * @stability stable
     */
    get requestInput(): DashboardWidgetGroupDefinitionWidgetChangeDefinitionRequest[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetCheckStatusDefinition {
    /**
     * The check to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#check Dashboard#check}
     *
     * @stability stable
     */
    readonly check: string;
    /**
     * The check group to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group Dashboard#group}
     *
     * @stability stable
     */
    readonly group?: string;
    /**
     * When `grouping = "cluster"`, indicates a list of tags to use for grouping.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: string[];
    /**
     * The kind of grouping to use. Valid values are `check`, `cluster`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#grouping Dashboard#grouping}
     *
     * @stability stable
     */
    readonly grouping: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * A list of tags to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags Dashboard#tags}
     *
     * @stability stable
     */
    readonly tags?: string[];
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetCheckStatusDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetCheckStatusDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetCheckStatusDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetCheckStatusDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetCheckStatusDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetCheckStatusDefinition | undefined);
    private _check?;
    /**
     * @stability stable
     */
    get check(): string;
    /**
     * @stability stable
     */
    set check(value: string);
    /**
     * @stability stable
     */
    get checkInput(): string | undefined;
    private _group?;
    /**
     * @stability stable
     */
    get group(): string;
    /**
     * @stability stable
     */
    set group(value: string);
    /**
     * @stability stable
     */
    resetGroup(): void;
    /**
     * @stability stable
     */
    get groupInput(): string | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): string[];
    /**
     * @stability stable
     */
    set groupBy(value: string[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): string[] | undefined;
    private _grouping?;
    /**
     * @stability stable
     */
    get grouping(): string;
    /**
     * @stability stable
     */
    set grouping(value: string);
    /**
     * @stability stable
     */
    get groupingInput(): string | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): string[];
    /**
     * @stability stable
     */
    set tags(value: string[]);
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): string[] | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestProcessQuery | undefined);
    private _filterBy?;
    /**
     * @stability stable
     */
    get filterBy(): string[];
    /**
     * @stability stable
     */
    set filterBy(value: string[]);
    /**
     * @stability stable
     */
    resetFilterBy(): void;
    /**
     * @stability stable
     */
    get filterByInput(): string[] | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _searchBy?;
    /**
     * @stability stable
     */
    get searchBy(): string;
    /**
     * @stability stable
     */
    set searchBy(value: string);
    /**
     * @stability stable
     */
    resetSearchBy(): void;
    /**
     * @stability stable
     */
    get searchByInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestStyle {
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestStyleToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestStyleOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestStyle): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestStyleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestStyle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestStyle | undefined);
    private _palette?;
    /**
     * @stability stable
     */
    get palette(): string;
    /**
     * @stability stable
     */
    set palette(value: string);
    /**
     * @stability stable
     */
    resetPalette(): void;
    /**
     * @stability stable
     */
    get paletteInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestApmQuery;
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestLogQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestProcessQuery;
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestRumQuery;
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestSecurityQuery;
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestStyle;
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequestToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequest): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetDistributionDefinition {
    /**
     * The size of the legend displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_size Dashboard#legend_size}
     *
     * @stability stable
     */
    readonly legendSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * Whether or not to show the legend on this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_legend Dashboard#show_legend}
     *
     * @stability stable
     */
    readonly showLegend?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequest[];
}
export declare function dashboardWidgetGroupDefinitionWidgetDistributionDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetDistributionDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetDistributionDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetDistributionDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinition | undefined);
    private _legendSize?;
    /**
     * @stability stable
     */
    get legendSize(): string;
    /**
     * @stability stable
     */
    set legendSize(value: string);
    /**
     * @stability stable
     */
    resetLegendSize(): void;
    /**
     * @stability stable
     */
    get legendSizeInput(): string | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _showLegend?;
    /**
     * @stability stable
     */
    get showLegend(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set showLegend(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShowLegend(): void;
    /**
     * @stability stable
     */
    get showLegendInput(): boolean | cdktf.IResolvable | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _request?;
    /**
     * @stability stable
     */
    get request(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequest[];
    /**
     * @stability stable
     */
    set request(value: DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequest[]);
    /**
     * @stability stable
     */
    resetRequest(): void;
    /**
     * @stability stable
     */
    get requestInput(): DashboardWidgetGroupDefinitionWidgetDistributionDefinitionRequest[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetEventStreamDefinition {
    /**
     * The size to use to display an event. Valid values are `s`, `l`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_size Dashboard#event_size}
     *
     * @stability stable
     */
    readonly eventSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * The execution method for multi-value filters, options: `and` or `or`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetEventStreamDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetEventStreamDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetEventStreamDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetEventStreamDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetEventStreamDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetEventStreamDefinition | undefined);
    private _eventSize?;
    /**
     * @stability stable
     */
    get eventSize(): string;
    /**
     * @stability stable
     */
    set eventSize(value: string);
    /**
     * @stability stable
     */
    resetEventSize(): void;
    /**
     * @stability stable
     */
    get eventSizeInput(): string | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
    private _tagsExecution?;
    /**
     * @stability stable
     */
    get tagsExecution(): string;
    /**
     * @stability stable
     */
    set tagsExecution(value: string);
    /**
     * @stability stable
     */
    resetTagsExecution(): void;
    /**
     * @stability stable
     */
    get tagsExecutionInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetEventTimelineDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * The execution method for multi-value filters, options: `and` or `or`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetEventTimelineDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetEventTimelineDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetEventTimelineDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetEventTimelineDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetEventTimelineDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetEventTimelineDefinition | undefined);
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
    private _tagsExecution?;
    /**
     * @stability stable
     */
    get tagsExecution(): string;
    /**
     * @stability stable
     */
    set tagsExecution(value: string);
    /**
     * @stability stable
     */
    resetTagsExecution(): void;
    /**
     * @stability stable
     */
    get tagsExecutionInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetFreeTextDefinition {
    /**
     * The color of the text in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#color Dashboard#color}
     *
     * @stability stable
     */
    readonly color?: string;
    /**
     * The size of the text in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#font_size Dashboard#font_size}
     *
     * @stability stable
     */
    readonly fontSize?: string;
    /**
     * The text to display in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text Dashboard#text}
     *
     * @stability stable
     */
    readonly text: string;
    /**
     * The alignment of the text in the widget. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetFreeTextDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetFreeTextDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetFreeTextDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetFreeTextDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetFreeTextDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetFreeTextDefinition | undefined);
    private _color?;
    /**
     * @stability stable
     */
    get color(): string;
    /**
     * @stability stable
     */
    set color(value: string);
    /**
     * @stability stable
     */
    resetColor(): void;
    /**
     * @stability stable
     */
    get colorInput(): string | undefined;
    private _fontSize?;
    /**
     * @stability stable
     */
    get fontSize(): string;
    /**
     * @stability stable
     */
    set fontSize(value: string);
    /**
     * @stability stable
     */
    resetFontSize(): void;
    /**
     * @stability stable
     */
    get fontSizeInput(): string | undefined;
    private _text?;
    /**
     * @stability stable
     */
    get text(): string;
    /**
     * @stability stable
     */
    set text(value: string);
    /**
     * @stability stable
     */
    get textInput(): string | undefined;
    private _textAlign?;
    /**
     * @stability stable
     */
    get textAlign(): string;
    /**
     * @stability stable
     */
    set textAlign(value: string);
    /**
     * @stability stable
     */
    resetTextAlign(): void;
    /**
     * @stability stable
     */
    get textAlignInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionCustomLinkToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionCustomLink): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaConditionalFormatsToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaConditionalFormats): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaLimitToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaLimitOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaLimit): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaLimitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaLimit | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaLimit | undefined);
    private _count?;
    /**
     * @stability stable
     */
    get count(): number;
    /**
     * @stability stable
     */
    set count(value: number);
    /**
     * @stability stable
     */
    resetCount(): void;
    /**
     * @stability stable
     */
    get countInput(): number | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    resetOrder(): void;
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaLimit;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormulaToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormula): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery {
    /**
     * The data source for APM Dependency Stats queries. Valid values are `apm_dependency_stats`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * APM Environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * Determines whether stats for upstream or downstream dependencies should be queried.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_upstream Dashboard#is_upstream}
     *
     * @stability stable
     */
    readonly isUpstream?: boolean | cdktf.IResolvable;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Name of operation on service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#operation_name Dashboard#operation_name}
     *
     * @stability stable
     */
    readonly operationName: string;
    /**
     * The name of the second primary tag used within APM; required when `primary_tag_value` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_name Dashboard#primary_tag_name}
     *
     * @stability stable
     */
    readonly primaryTagName?: string;
    /**
     * Filter APM data by the second primary tag. `primary_tag_name` must also be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_value Dashboard#primary_tag_value}
     *
     * @stability stable
     */
    readonly primaryTagValue?: string;
    /**
     * APM resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#resource_name Dashboard#resource_name}
     *
     * @stability stable
     */
    readonly resourceName: string;
    /**
     * APM service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * APM statistic. Valid values are `avg_duration`, `avg_root_duration`, `avg_spans_per_trace`, `error_rate`, `pct_exec_time`, `pct_of_traces`, `total_traces_count`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#stat Dashboard#stat}
     *
     * @stability stable
     */
    readonly stat: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmDependencyStatsQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmDependencyStatsQueryOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmDependencyStatsQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _env?;
    /**
     * @stability stable
     */
    get env(): string;
    /**
     * @stability stable
     */
    set env(value: string);
    /**
     * @stability stable
     */
    get envInput(): string | undefined;
    private _isUpstream?;
    /**
     * @stability stable
     */
    get isUpstream(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isUpstream(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsUpstream(): void;
    /**
     * @stability stable
     */
    get isUpstreamInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _operationName?;
    /**
     * @stability stable
     */
    get operationName(): string;
    /**
     * @stability stable
     */
    set operationName(value: string);
    /**
     * @stability stable
     */
    get operationNameInput(): string | undefined;
    private _primaryTagName?;
    /**
     * @stability stable
     */
    get primaryTagName(): string;
    /**
     * @stability stable
     */
    set primaryTagName(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagName(): void;
    /**
     * @stability stable
     */
    get primaryTagNameInput(): string | undefined;
    private _primaryTagValue?;
    /**
     * @stability stable
     */
    get primaryTagValue(): string;
    /**
     * @stability stable
     */
    set primaryTagValue(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagValue(): void;
    /**
     * @stability stable
     */
    get primaryTagValueInput(): string | undefined;
    private _resourceName?;
    /**
     * @stability stable
     */
    get resourceName(): string;
    /**
     * @stability stable
     */
    set resourceName(value: string);
    /**
     * @stability stable
     */
    get resourceNameInput(): string | undefined;
    private _service?;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string | undefined;
    private _stat?;
    /**
     * @stability stable
     */
    get stat(): string;
    /**
     * @stability stable
     */
    set stat(value: string);
    /**
     * @stability stable
     */
    get statInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery {
    /**
     * The data source for APM Resource Stats queries. Valid values are `apm_resource_stats`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * APM Environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * Array of fields to group results by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Name of operation on service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#operation_name Dashboard#operation_name}
     *
     * @stability stable
     */
    readonly operationName?: string;
    /**
     * The name of the second primary tag used within APM; required when `primary_tag_value` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_name Dashboard#primary_tag_name}
     *
     * @stability stable
     */
    readonly primaryTagName?: string;
    /**
     * Filter APM data by the second primary tag. `primary_tag_name` must also be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_value Dashboard#primary_tag_value}
     *
     * @stability stable
     */
    readonly primaryTagValue?: string;
    /**
     * APM resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#resource_name Dashboard#resource_name}
     *
     * @stability stable
     */
    readonly resourceName?: string;
    /**
     * APM service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * APM statistic. Valid values are `errors`, `error_rate`, `hits`, `latency_avg`, `latency_max`, `latency_p50`, `latency_p75`, `latency_p90`, `latency_p95`, `latency_p99`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#stat Dashboard#stat}
     *
     * @stability stable
     */
    readonly stat: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmResourceStatsQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmResourceStatsQueryOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmResourceStatsQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _env?;
    /**
     * @stability stable
     */
    get env(): string;
    /**
     * @stability stable
     */
    set env(value: string);
    /**
     * @stability stable
     */
    get envInput(): string | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): string[];
    /**
     * @stability stable
     */
    set groupBy(value: string[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _operationName?;
    /**
     * @stability stable
     */
    get operationName(): string;
    /**
     * @stability stable
     */
    set operationName(value: string);
    /**
     * @stability stable
     */
    resetOperationName(): void;
    /**
     * @stability stable
     */
    get operationNameInput(): string | undefined;
    private _primaryTagName?;
    /**
     * @stability stable
     */
    get primaryTagName(): string;
    /**
     * @stability stable
     */
    set primaryTagName(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagName(): void;
    /**
     * @stability stable
     */
    get primaryTagNameInput(): string | undefined;
    private _primaryTagValue?;
    /**
     * @stability stable
     */
    get primaryTagValue(): string;
    /**
     * @stability stable
     */
    set primaryTagValue(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagValue(): void;
    /**
     * @stability stable
     */
    get primaryTagValueInput(): string | undefined;
    private _resourceName?;
    /**
     * @stability stable
     */
    get resourceName(): string;
    /**
     * @stability stable
     */
    set resourceName(value: string);
    /**
     * @stability stable
     */
    resetResourceName(): void;
    /**
     * @stability stable
     */
    get resourceNameInput(): string | undefined;
    private _service?;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string | undefined;
    private _stat?;
    /**
     * @stability stable
     */
    get stat(): string;
    /**
     * @stability stable
     */
    set stat(value: string);
    /**
     * @stability stable
     */
    get statInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBySortToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBySortOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBySortOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    resetMetric(): void;
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    resetOrder(): void;
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBySort;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearchToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearchOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearch): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearch | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearch | undefined);
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearch;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _indexes?;
    /**
     * @stability stable
     */
    get indexes(): string[];
    /**
     * @stability stable
     */
    set indexes(value: string[]);
    /**
     * @stability stable
     */
    resetIndexes(): void;
    /**
     * @stability stable
     */
    get indexesInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _compute?;
    /**
     * @stability stable
     */
    get compute(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryCompute[];
    /**
     * @stability stable
     */
    set compute(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryCompute[]);
    /**
     * @stability stable
     */
    get computeInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryCompute[] | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQueryGroupBy[] | undefined;
    private _search;
    /**
     * @stability stable
     */
    get search(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearchOutputReference;
    /**
     * @stability stable
     */
    putSearch(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearch): void;
    /**
     * @stability stable
     */
    resetSearch(): void;
    /**
     * @stability stable
     */
    get searchInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuerySearch | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryMetricQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryMetricQueryOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryMetricQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryMetricQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryMetricQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryMetricQuery | undefined);
    private _aggregator?;
    /**
     * @stability stable
     */
    get aggregator(): string;
    /**
     * @stability stable
     */
    set aggregator(value: string);
    /**
     * @stability stable
     */
    resetAggregator(): void;
    /**
     * @stability stable
     */
    get aggregatorInput(): string | undefined;
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    resetDataSource(): void;
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryProcessQuery | undefined);
    private _aggregator?;
    /**
     * @stability stable
     */
    get aggregator(): string;
    /**
     * @stability stable
     */
    set aggregator(value: string);
    /**
     * @stability stable
     */
    resetAggregator(): void;
    /**
     * @stability stable
     */
    get aggregatorInput(): string | undefined;
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _isNormalizedCpu?;
    /**
     * @stability stable
     */
    get isNormalizedCpu(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isNormalizedCpu(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsNormalizedCpu(): void;
    /**
     * @stability stable
     */
    get isNormalizedCpuInput(): boolean | cdktf.IResolvable | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _sort?;
    /**
     * @stability stable
     */
    get sort(): string;
    /**
     * @stability stable
     */
    set sort(value: string);
    /**
     * @stability stable
     */
    resetSort(): void;
    /**
     * @stability stable
     */
    get sortInput(): string | undefined;
    private _tagFilters?;
    /**
     * @stability stable
     */
    get tagFilters(): string[];
    /**
     * @stability stable
     */
    set tagFilters(value: string[]);
    /**
     * @stability stable
     */
    resetTagFilters(): void;
    /**
     * @stability stable
     */
    get tagFiltersInput(): string[] | undefined;
    private _textFilter?;
    /**
     * @stability stable
     */
    get textFilter(): string;
    /**
     * @stability stable
     */
    set textFilter(value: string);
    /**
     * @stability stable
     */
    resetTextFilter(): void;
    /**
     * @stability stable
     */
    get textFilterInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQuery {
    /**
     * apm_dependency_stats_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_dependency_stats_query Dashboard#apm_dependency_stats_query}
     *
     * @stability stable
     */
    readonly apmDependencyStatsQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmDependencyStatsQuery;
    /**
     * apm_resource_stats_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_resource_stats_query Dashboard#apm_resource_stats_query}
     *
     * @stability stable
     */
    readonly apmResourceStatsQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryApmResourceStatsQuery;
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryEventQuery;
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryMetricQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryProcessQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQuery): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestLogQuery;
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestRumQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequestToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequest): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyle {
    /**
     * The color palette to apply to the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * A Boolean indicating whether to flip the palette tones.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette_flip Dashboard#palette_flip}
     *
     * @stability stable
     */
    readonly paletteFlip: boolean | cdktf.IResolvable;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyleToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyleOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyle): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyle | undefined);
    private _palette?;
    /**
     * @stability stable
     */
    get palette(): string;
    /**
     * @stability stable
     */
    set palette(value: string);
    /**
     * @stability stable
     */
    get paletteInput(): string | undefined;
    private _paletteFlip?;
    /**
     * @stability stable
     */
    get paletteFlip(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set paletteFlip(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    get paletteFlipInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinitionView {
    /**
     * The two-letter ISO code of a country to focus the map on (or `WORLD`).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#focus Dashboard#focus}
     *
     * @stability stable
     */
    readonly focus: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionViewToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionViewOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinitionView): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionViewOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionView | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionView | undefined);
    private _focus?;
    /**
     * @stability stable
     */
    get focus(): string;
    /**
     * @stability stable
     */
    set focus(value: string);
    /**
     * @stability stable
     */
    get focusInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetGeomapDefinition {
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequest[];
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyle;
    /**
     * view block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#view Dashboard#view}
     *
     * @stability stable
     */
    readonly view: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionView;
}
export declare function dashboardWidgetGroupDefinitionWidgetGeomapDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetGeomapDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetGeomapDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetGeomapDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinition | undefined);
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _customLink?;
    /**
     * @stability stable
     */
    get customLink(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionCustomLink[];
    /**
     * @stability stable
     */
    set customLink(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionCustomLink[]);
    /**
     * @stability stable
     */
    resetCustomLink(): void;
    /**
     * @stability stable
     */
    get customLinkInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionCustomLink[] | undefined;
    private _request?;
    /**
     * @stability stable
     */
    get request(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequest[];
    /**
     * @stability stable
     */
    set request(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequest[]);
    /**
     * @stability stable
     */
    resetRequest(): void;
    /**
     * @stability stable
     */
    get requestInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionRequest[] | undefined;
    private _style;
    /**
     * @stability stable
     */
    get style(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyleOutputReference;
    /**
     * @stability stable
     */
    putStyle(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyle): void;
    /**
     * @stability stable
     */
    resetStyle(): void;
    /**
     * @stability stable
     */
    get styleInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionStyle | undefined;
    private _view;
    /**
     * @stability stable
     */
    get view(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionViewOutputReference;
    /**
     * @stability stable
     */
    putView(value: DashboardWidgetGroupDefinitionWidgetGeomapDefinitionView): void;
    /**
     * @stability stable
     */
    get viewInput(): DashboardWidgetGroupDefinitionWidgetGeomapDefinitionView | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionCustomLinkToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionCustomLink): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionEvent {
    /**
     * The event query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q: string;
    /**
     * The execution method for multi-value filters.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionEventToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionEvent): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestProcessQuery | undefined);
    private _filterBy?;
    /**
     * @stability stable
     */
    get filterBy(): string[];
    /**
     * @stability stable
     */
    set filterBy(value: string[]);
    /**
     * @stability stable
     */
    resetFilterBy(): void;
    /**
     * @stability stable
     */
    get filterByInput(): string[] | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _searchBy?;
    /**
     * @stability stable
     */
    get searchBy(): string;
    /**
     * @stability stable
     */
    set searchBy(value: string);
    /**
     * @stability stable
     */
    resetSearchBy(): void;
    /**
     * @stability stable
     */
    get searchByInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestStyle {
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestStyleToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestStyleOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestStyle): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestStyleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestStyle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestStyle | undefined);
    private _palette?;
    /**
     * @stability stable
     */
    get palette(): string;
    /**
     * @stability stable
     */
    set palette(value: string);
    /**
     * @stability stable
     */
    resetPalette(): void;
    /**
     * @stability stable
     */
    get paletteInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequest {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestApmQuery;
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestLogQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestProcessQuery;
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestRumQuery;
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestSecurityQuery;
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestStyle;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequestToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequest): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxisToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxisOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxis): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxisOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxis | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxis | undefined);
    private _includeZero?;
    /**
     * @stability stable
     */
    get includeZero(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set includeZero(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIncludeZero(): void;
    /**
     * @stability stable
     */
    get includeZeroInput(): boolean | cdktf.IResolvable | undefined;
    private _label?;
    /**
     * @stability stable
     */
    get label(): string;
    /**
     * @stability stable
     */
    set label(value: string);
    /**
     * @stability stable
     */
    resetLabel(): void;
    /**
     * @stability stable
     */
    get labelInput(): string | undefined;
    private _max?;
    /**
     * @stability stable
     */
    get max(): string;
    /**
     * @stability stable
     */
    set max(value: string);
    /**
     * @stability stable
     */
    resetMax(): void;
    /**
     * @stability stable
     */
    get maxInput(): string | undefined;
    private _min?;
    /**
     * @stability stable
     */
    get min(): string;
    /**
     * @stability stable
     */
    set min(value: string);
    /**
     * @stability stable
     */
    resetMin(): void;
    /**
     * @stability stable
     */
    get minInput(): string | undefined;
    private _scale?;
    /**
     * @stability stable
     */
    get scale(): string;
    /**
     * @stability stable
     */
    set scale(value: string);
    /**
     * @stability stable
     */
    resetScale(): void;
    /**
     * @stability stable
     */
    get scaleInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHeatmapDefinition {
    /**
     * The size of the legend displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#legend_size Dashboard#legend_size}
     *
     * @stability stable
     */
    readonly legendSize?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * Whether or not to show the legend on this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_legend Dashboard#show_legend}
     *
     * @stability stable
     */
    readonly showLegend?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionCustomLink[];
    /**
     * event block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event Dashboard#event}
     *
     * @stability stable
     */
    readonly event?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionEvent[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequest[];
    /**
     * yaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#yaxis Dashboard#yaxis}
     *
     * @stability stable
     */
    readonly yaxis?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxis;
}
export declare function dashboardWidgetGroupDefinitionWidgetHeatmapDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetHeatmapDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinition | undefined);
    private _legendSize?;
    /**
     * @stability stable
     */
    get legendSize(): string;
    /**
     * @stability stable
     */
    set legendSize(value: string);
    /**
     * @stability stable
     */
    resetLegendSize(): void;
    /**
     * @stability stable
     */
    get legendSizeInput(): string | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _showLegend?;
    /**
     * @stability stable
     */
    get showLegend(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set showLegend(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShowLegend(): void;
    /**
     * @stability stable
     */
    get showLegendInput(): boolean | cdktf.IResolvable | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _customLink?;
    /**
     * @stability stable
     */
    get customLink(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionCustomLink[];
    /**
     * @stability stable
     */
    set customLink(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionCustomLink[]);
    /**
     * @stability stable
     */
    resetCustomLink(): void;
    /**
     * @stability stable
     */
    get customLinkInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionCustomLink[] | undefined;
    private _event?;
    /**
     * @stability stable
     */
    get event(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionEvent[];
    /**
     * @stability stable
     */
    set event(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionEvent[]);
    /**
     * @stability stable
     */
    resetEvent(): void;
    /**
     * @stability stable
     */
    get eventInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionEvent[] | undefined;
    private _request?;
    /**
     * @stability stable
     */
    get request(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequest[];
    /**
     * @stability stable
     */
    set request(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequest[]);
    /**
     * @stability stable
     */
    resetRequest(): void;
    /**
     * @stability stable
     */
    get requestInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionRequest[] | undefined;
    private _yaxis;
    /**
     * @stability stable
     */
    get yaxis(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxisOutputReference;
    /**
     * @stability stable
     */
    putYaxis(value: DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxis): void;
    /**
     * @stability stable
     */
    resetYaxis(): void;
    /**
     * @stability stable
     */
    get yaxisInput(): DashboardWidgetGroupDefinitionWidgetHeatmapDefinitionYaxis | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionCustomLinkToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionCustomLink): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillProcessQuery | undefined);
    private _filterBy?;
    /**
     * @stability stable
     */
    get filterBy(): string[];
    /**
     * @stability stable
     */
    set filterBy(value: string[]);
    /**
     * @stability stable
     */
    resetFilterBy(): void;
    /**
     * @stability stable
     */
    get filterByInput(): string[] | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _searchBy?;
    /**
     * @stability stable
     */
    get searchBy(): string;
    /**
     * @stability stable
     */
    set searchBy(value: string);
    /**
     * @stability stable
     */
    resetSearchBy(): void;
    /**
     * @stability stable
     */
    get searchByInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFill {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillApmQuery;
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillLogQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillProcessQuery;
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillRumQuery;
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillSecurityQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFillToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFill): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeProcessQuery | undefined);
    private _filterBy?;
    /**
     * @stability stable
     */
    get filterBy(): string[];
    /**
     * @stability stable
     */
    set filterBy(value: string[]);
    /**
     * @stability stable
     */
    resetFilterBy(): void;
    /**
     * @stability stable
     */
    get filterByInput(): string[] | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _searchBy?;
    /**
     * @stability stable
     */
    get searchBy(): string;
    /**
     * @stability stable
     */
    set searchBy(value: string);
    /**
     * @stability stable
     */
    resetSearchBy(): void;
    /**
     * @stability stable
     */
    get searchByInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSize {
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeApmQuery;
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeLogQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeProcessQuery;
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeRumQuery;
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeSecurityQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSizeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSize): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequest {
    /**
     * fill block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#fill Dashboard#fill}
     *
     * @stability stable
     */
    readonly fill?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFill[];
    /**
     * size block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#size Dashboard#size}
     *
     * @stability stable
     */
    readonly size?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSize[];
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequest): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequest | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequest | undefined);
    private _fill?;
    /**
     * @stability stable
     */
    get fill(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFill[];
    /**
     * @stability stable
     */
    set fill(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFill[]);
    /**
     * @stability stable
     */
    resetFill(): void;
    /**
     * @stability stable
     */
    get fillInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestFill[] | undefined;
    private _size?;
    /**
     * @stability stable
     */
    get size(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSize[];
    /**
     * @stability stable
     */
    set size(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSize[]);
    /**
     * @stability stable
     */
    resetSize(): void;
    /**
     * @stability stable
     */
    get sizeInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestSize[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyle {
    /**
     * The max value to use to color the map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#fill_max Dashboard#fill_max}
     *
     * @stability stable
     */
    readonly fillMax?: string;
    /**
     * The min value to use to color the map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#fill_min Dashboard#fill_min}
     *
     * @stability stable
     */
    readonly fillMin?: string;
    /**
     * A color palette to apply to the widget. The available options are available at: https://docs.datadoghq.com/dashboards/widgets/timeseries/#appearance.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette?: string;
    /**
     * A Boolean indicating whether to flip the palette tones.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette_flip Dashboard#palette_flip}
     *
     * @stability stable
     */
    readonly paletteFlip?: boolean | cdktf.IResolvable;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyleToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyleOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyle): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyleOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyle | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyle | undefined);
    private _fillMax?;
    /**
     * @stability stable
     */
    get fillMax(): string;
    /**
     * @stability stable
     */
    set fillMax(value: string);
    /**
     * @stability stable
     */
    resetFillMax(): void;
    /**
     * @stability stable
     */
    get fillMaxInput(): string | undefined;
    private _fillMin?;
    /**
     * @stability stable
     */
    get fillMin(): string;
    /**
     * @stability stable
     */
    set fillMin(value: string);
    /**
     * @stability stable
     */
    resetFillMin(): void;
    /**
     * @stability stable
     */
    get fillMinInput(): string | undefined;
    private _palette?;
    /**
     * @stability stable
     */
    get palette(): string;
    /**
     * @stability stable
     */
    set palette(value: string);
    /**
     * @stability stable
     */
    resetPalette(): void;
    /**
     * @stability stable
     */
    get paletteInput(): string | undefined;
    private _paletteFlip?;
    /**
     * @stability stable
     */
    get paletteFlip(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set paletteFlip(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetPaletteFlip(): void;
    /**
     * @stability stable
     */
    get paletteFlipInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetHostmapDefinition {
    /**
     * The list of tags to group nodes by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group Dashboard#group}
     *
     * @stability stable
     */
    readonly group?: string[];
    /**
     * A Boolean indicating whether to show ungrouped nodes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#no_group_hosts Dashboard#no_group_hosts}
     *
     * @stability stable
     */
    readonly noGroupHosts?: boolean | cdktf.IResolvable;
    /**
     * A Boolean indicating whether to show nodes with no metrics.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#no_metric_hosts Dashboard#no_metric_hosts}
     *
     * @stability stable
     */
    readonly noMetricHosts?: boolean | cdktf.IResolvable;
    /**
     * The type of node used. Valid values are `host`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#node_type Dashboard#node_type}
     *
     * @stability stable
     */
    readonly nodeType?: string;
    /**
     * The list of tags to filter nodes by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scope Dashboard#scope}
     *
     * @stability stable
     */
    readonly scope?: string[];
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequest;
    /**
     * style block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#style Dashboard#style}
     *
     * @stability stable
     */
    readonly style?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyle;
}
export declare function dashboardWidgetGroupDefinitionWidgetHostmapDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetHostmapDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetHostmapDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetHostmapDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinition | undefined);
    private _group?;
    /**
     * @stability stable
     */
    get group(): string[];
    /**
     * @stability stable
     */
    set group(value: string[]);
    /**
     * @stability stable
     */
    resetGroup(): void;
    /**
     * @stability stable
     */
    get groupInput(): string[] | undefined;
    private _noGroupHosts?;
    /**
     * @stability stable
     */
    get noGroupHosts(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set noGroupHosts(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetNoGroupHosts(): void;
    /**
     * @stability stable
     */
    get noGroupHostsInput(): boolean | cdktf.IResolvable | undefined;
    private _noMetricHosts?;
    /**
     * @stability stable
     */
    get noMetricHosts(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set noMetricHosts(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetNoMetricHosts(): void;
    /**
     * @stability stable
     */
    get noMetricHostsInput(): boolean | cdktf.IResolvable | undefined;
    private _nodeType?;
    /**
     * @stability stable
     */
    get nodeType(): string;
    /**
     * @stability stable
     */
    set nodeType(value: string);
    /**
     * @stability stable
     */
    resetNodeType(): void;
    /**
     * @stability stable
     */
    get nodeTypeInput(): string | undefined;
    private _scope?;
    /**
     * @stability stable
     */
    get scope(): string[];
    /**
     * @stability stable
     */
    set scope(value: string[]);
    /**
     * @stability stable
     */
    resetScope(): void;
    /**
     * @stability stable
     */
    get scopeInput(): string[] | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _customLink?;
    /**
     * @stability stable
     */
    get customLink(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionCustomLink[];
    /**
     * @stability stable
     */
    set customLink(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionCustomLink[]);
    /**
     * @stability stable
     */
    resetCustomLink(): void;
    /**
     * @stability stable
     */
    get customLinkInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionCustomLink[] | undefined;
    private _request;
    /**
     * @stability stable
     */
    get request(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequestOutputReference;
    /**
     * @stability stable
     */
    putRequest(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequest): void;
    /**
     * @stability stable
     */
    resetRequest(): void;
    /**
     * @stability stable
     */
    get requestInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionRequest | undefined;
    private _style;
    /**
     * @stability stable
     */
    get style(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyleOutputReference;
    /**
     * @stability stable
     */
    putStyle(value: DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyle): void;
    /**
     * @stability stable
     */
    resetStyle(): void;
    /**
     * @stability stable
     */
    get styleInput(): DashboardWidgetGroupDefinitionWidgetHostmapDefinitionStyle | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetIframeDefinition {
    /**
     * The URL to use as a data source for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#url Dashboard#url}
     *
     * @stability stable
     */
    readonly url: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetIframeDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetIframeDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetIframeDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetIframeDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetIframeDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetIframeDefinition | undefined);
    private _url?;
    /**
     * @stability stable
     */
    get url(): string;
    /**
     * @stability stable
     */
    set url(value: string);
    /**
     * @stability stable
     */
    get urlInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetImageDefinition {
    /**
     * Whether to display a background or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_background Dashboard#has_background}
     *
     * @stability stable
     */
    readonly hasBackground?: boolean | cdktf.IResolvable;
    /**
     * Whether to display a border or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_border Dashboard#has_border}
     *
     * @stability stable
     */
    readonly hasBorder?: boolean | cdktf.IResolvable;
    /**
     * The horizontal alignment for the widget. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#horizontal_align Dashboard#horizontal_align}
     *
     * @stability stable
     */
    readonly horizontalAlign?: string;
    /**
     * The margins to use around the image.
     *
     * Note: `small` and `large` values are deprecated. Valid values are `sm`, `md`, `lg`, `small`, `large`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#margin Dashboard#margin}
     *
     * @stability stable
     */
    readonly margin?: string;
    /**
     * The preferred method to adapt the dimensions of the image.
     *
     * The values are based on the image `object-fit` CSS properties. Note: `zoom`, `fit` and `center` values are deprecated. Valid values are `fill`, `contain`, `cover`, `none`, `scale-down`, `zoom`, `fit`, `center`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sizing Dashboard#sizing}
     *
     * @stability stable
     */
    readonly sizing?: string;
    /**
     * The URL to use as a data source for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#url Dashboard#url}
     *
     * @stability stable
     */
    readonly url: string;
    /**
     * The URL in dark mode to use as a data source for the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#url_dark_theme Dashboard#url_dark_theme}
     *
     * @stability stable
     */
    readonly urlDarkTheme?: string;
    /**
     * The vertical alignment for the widget. Valid values are `center`, `top`, `bottom`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#vertical_align Dashboard#vertical_align}
     *
     * @stability stable
     */
    readonly verticalAlign?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetImageDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetImageDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetImageDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetImageDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetImageDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetImageDefinition | undefined);
    private _hasBackground?;
    /**
     * @stability stable
     */
    get hasBackground(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hasBackground(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHasBackground(): void;
    /**
     * @stability stable
     */
    get hasBackgroundInput(): boolean | cdktf.IResolvable | undefined;
    private _hasBorder?;
    /**
     * @stability stable
     */
    get hasBorder(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hasBorder(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHasBorder(): void;
    /**
     * @stability stable
     */
    get hasBorderInput(): boolean | cdktf.IResolvable | undefined;
    private _horizontalAlign?;
    /**
     * @stability stable
     */
    get horizontalAlign(): string;
    /**
     * @stability stable
     */
    set horizontalAlign(value: string);
    /**
     * @stability stable
     */
    resetHorizontalAlign(): void;
    /**
     * @stability stable
     */
    get horizontalAlignInput(): string | undefined;
    private _margin?;
    /**
     * @stability stable
     */
    get margin(): string;
    /**
     * @stability stable
     */
    set margin(value: string);
    /**
     * @stability stable
     */
    resetMargin(): void;
    /**
     * @stability stable
     */
    get marginInput(): string | undefined;
    private _sizing?;
    /**
     * @stability stable
     */
    get sizing(): string;
    /**
     * @stability stable
     */
    set sizing(value: string);
    /**
     * @stability stable
     */
    resetSizing(): void;
    /**
     * @stability stable
     */
    get sizingInput(): string | undefined;
    private _url?;
    /**
     * @stability stable
     */
    get url(): string;
    /**
     * @stability stable
     */
    set url(value: string);
    /**
     * @stability stable
     */
    get urlInput(): string | undefined;
    private _urlDarkTheme?;
    /**
     * @stability stable
     */
    get urlDarkTheme(): string;
    /**
     * @stability stable
     */
    set urlDarkTheme(value: string);
    /**
     * @stability stable
     */
    resetUrlDarkTheme(): void;
    /**
     * @stability stable
     */
    get urlDarkThemeInput(): string | undefined;
    private _verticalAlign?;
    /**
     * @stability stable
     */
    get verticalAlign(): string;
    /**
     * @stability stable
     */
    set verticalAlign(value: string);
    /**
     * @stability stable
     */
    resetVerticalAlign(): void;
    /**
     * @stability stable
     */
    get verticalAlignInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSort {
    /**
     * The facet path for the column.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#column Dashboard#column}
     *
     * @stability stable
     */
    readonly column: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSortToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSortOutputReference | DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSort): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSortOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSort | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSort | undefined);
    private _column?;
    /**
     * @stability stable
     */
    get column(): string;
    /**
     * @stability stable
     */
    set column(value: string);
    /**
     * @stability stable
     */
    get columnInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetLogStreamDefinition {
    /**
     * Stringified list of columns to use, for example: `["column1","column2","column3"]`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#columns Dashboard#columns}
     *
     * @stability stable
     */
    readonly columns?: string[];
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The number of log lines to display. Valid values are `inline`, `expanded-md`, `expanded-lg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#message_display Dashboard#message_display}
     *
     * @stability stable
     */
    readonly messageDisplay?: string;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: string;
    /**
     * If the date column should be displayed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_date_column Dashboard#show_date_column}
     *
     * @stability stable
     */
    readonly showDateColumn?: boolean | cdktf.IResolvable;
    /**
     * If the message column should be displayed.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_message_column Dashboard#show_message_column}
     *
     * @stability stable
     */
    readonly showMessageColumn?: boolean | cdktf.IResolvable;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSort;
}
export declare function dashboardWidgetGroupDefinitionWidgetLogStreamDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetLogStreamDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetLogStreamDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetLogStreamDefinition | undefined);
    private _columns?;
    /**
     * @stability stable
     */
    get columns(): string[];
    /**
     * @stability stable
     */
    set columns(value: string[]);
    /**
     * @stability stable
     */
    resetColumns(): void;
    /**
     * @stability stable
     */
    get columnsInput(): string[] | undefined;
    private _indexes?;
    /**
     * @stability stable
     */
    get indexes(): string[];
    /**
     * @stability stable
     */
    set indexes(value: string[]);
    /**
     * @stability stable
     */
    resetIndexes(): void;
    /**
     * @stability stable
     */
    get indexesInput(): string[] | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _messageDisplay?;
    /**
     * @stability stable
     */
    get messageDisplay(): string;
    /**
     * @stability stable
     */
    set messageDisplay(value: string);
    /**
     * @stability stable
     */
    resetMessageDisplay(): void;
    /**
     * @stability stable
     */
    get messageDisplayInput(): string | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    resetQuery(): void;
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
    private _showDateColumn?;
    /**
     * @stability stable
     */
    get showDateColumn(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set showDateColumn(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShowDateColumn(): void;
    /**
     * @stability stable
     */
    get showDateColumnInput(): boolean | cdktf.IResolvable | undefined;
    private _showMessageColumn?;
    /**
     * @stability stable
     */
    get showMessageColumn(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set showMessageColumn(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShowMessageColumn(): void;
    /**
     * @stability stable
     */
    get showMessageColumnInput(): boolean | cdktf.IResolvable | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _sort;
    /**
     * @stability stable
     */
    get sort(): DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSortOutputReference;
    /**
     * @stability stable
     */
    putSort(value: DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSort): void;
    /**
     * @stability stable
     */
    resetSort(): void;
    /**
     * @stability stable
     */
    get sortInput(): DashboardWidgetGroupDefinitionWidgetLogStreamDefinitionSort | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetManageStatusDefinition {
    /**
     * Whether to colorize text or background. Valid values are `background`, `text`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#color_preference Dashboard#color_preference}
     *
     * @stability stable
     */
    readonly colorPreference?: string;
    /**
     * The display setting to use. Valid values are `counts`, `countsAndList`, `list`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#display_format Dashboard#display_format}
     *
     * @stability stable
     */
    readonly displayFormat?: string;
    /**
     * A Boolean indicating whether to hide empty categories.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_zero_counts Dashboard#hide_zero_counts}
     *
     * @stability stable
     */
    readonly hideZeroCounts?: boolean | cdktf.IResolvable;
    /**
     * The query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
    /**
     * A Boolean indicating whether to show when monitors/groups last triggered.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_last_triggered Dashboard#show_last_triggered}
     *
     * @stability stable
     */
    readonly showLastTriggered?: boolean | cdktf.IResolvable;
    /**
     * The method to sort the monitors.
     *
     * Valid values are `name`, `group`, `status`, `tags`, `triggered`, `group,asc`, `group,desc`, `name,asc`, `name,desc`, `status,asc`, `status,desc`, `tags,asc`, `tags,desc`, `triggered,asc`, `triggered,desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * The summary type to use. Valid values are `monitors`, `groups`, `combined`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#summary_type Dashboard#summary_type}
     *
     * @stability stable
     */
    readonly summaryType?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetManageStatusDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetManageStatusDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetManageStatusDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetManageStatusDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetManageStatusDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetManageStatusDefinition | undefined);
    private _colorPreference?;
    /**
     * @stability stable
     */
    get colorPreference(): string;
    /**
     * @stability stable
     */
    set colorPreference(value: string);
    /**
     * @stability stable
     */
    resetColorPreference(): void;
    /**
     * @stability stable
     */
    get colorPreferenceInput(): string | undefined;
    private _displayFormat?;
    /**
     * @stability stable
     */
    get displayFormat(): string;
    /**
     * @stability stable
     */
    set displayFormat(value: string);
    /**
     * @stability stable
     */
    resetDisplayFormat(): void;
    /**
     * @stability stable
     */
    get displayFormatInput(): string | undefined;
    private _hideZeroCounts?;
    /**
     * @stability stable
     */
    get hideZeroCounts(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hideZeroCounts(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHideZeroCounts(): void;
    /**
     * @stability stable
     */
    get hideZeroCountsInput(): boolean | cdktf.IResolvable | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
    private _showLastTriggered?;
    /**
     * @stability stable
     */
    get showLastTriggered(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set showLastTriggered(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShowLastTriggered(): void;
    /**
     * @stability stable
     */
    get showLastTriggeredInput(): boolean | cdktf.IResolvable | undefined;
    private _sort?;
    /**
     * @stability stable
     */
    get sort(): string;
    /**
     * @stability stable
     */
    set sort(value: string);
    /**
     * @stability stable
     */
    resetSort(): void;
    /**
     * @stability stable
     */
    get sortInput(): string | undefined;
    private _summaryType?;
    /**
     * @stability stable
     */
    get summaryType(): string;
    /**
     * @stability stable
     */
    set summaryType(value: string);
    /**
     * @stability stable
     */
    resetSummaryType(): void;
    /**
     * @stability stable
     */
    get summaryTypeInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetNoteDefinition {
    /**
     * The background color of the note.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#background_color Dashboard#background_color}
     *
     * @stability stable
     */
    readonly backgroundColor?: string;
    /**
     * The content of the note.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#content Dashboard#content}
     *
     * @stability stable
     */
    readonly content: string;
    /**
     * The size of the text.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#font_size Dashboard#font_size}
     *
     * @stability stable
     */
    readonly fontSize?: string;
    /**
     * Whether to add padding or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_padding Dashboard#has_padding}
     *
     * @stability stable
     */
    readonly hasPadding?: boolean | cdktf.IResolvable;
    /**
     * Whether to show a tick or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_tick Dashboard#show_tick}
     *
     * @stability stable
     */
    readonly showTick?: boolean | cdktf.IResolvable;
    /**
     * The alignment of the widget's text. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
    /**
     * When `tick = true`, a string indicating on which side of the widget the tick should be displayed.
     *
     * Valid values are `bottom`, `left`, `right`, `top`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tick_edge Dashboard#tick_edge}
     *
     * @stability stable
     */
    readonly tickEdge?: string;
    /**
     * When `tick = true`, a string with a percent sign indicating the position of the tick, for example: `tick_pos = "50%"` is centered alignment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tick_pos Dashboard#tick_pos}
     *
     * @stability stable
     */
    readonly tickPos?: string;
    /**
     * The vertical alignment for the widget. Valid values are `center`, `top`, `bottom`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#vertical_align Dashboard#vertical_align}
     *
     * @stability stable
     */
    readonly verticalAlign?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetNoteDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetNoteDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetNoteDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetNoteDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetNoteDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetNoteDefinition | undefined);
    private _backgroundColor?;
    /**
     * @stability stable
     */
    get backgroundColor(): string;
    /**
     * @stability stable
     */
    set backgroundColor(value: string);
    /**
     * @stability stable
     */
    resetBackgroundColor(): void;
    /**
     * @stability stable
     */
    get backgroundColorInput(): string | undefined;
    private _content?;
    /**
     * @stability stable
     */
    get content(): string;
    /**
     * @stability stable
     */
    set content(value: string);
    /**
     * @stability stable
     */
    get contentInput(): string | undefined;
    private _fontSize?;
    /**
     * @stability stable
     */
    get fontSize(): string;
    /**
     * @stability stable
     */
    set fontSize(value: string);
    /**
     * @stability stable
     */
    resetFontSize(): void;
    /**
     * @stability stable
     */
    get fontSizeInput(): string | undefined;
    private _hasPadding?;
    /**
     * @stability stable
     */
    get hasPadding(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set hasPadding(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetHasPadding(): void;
    /**
     * @stability stable
     */
    get hasPaddingInput(): boolean | cdktf.IResolvable | undefined;
    private _showTick?;
    /**
     * @stability stable
     */
    get showTick(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set showTick(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShowTick(): void;
    /**
     * @stability stable
     */
    get showTickInput(): boolean | cdktf.IResolvable | undefined;
    private _textAlign?;
    /**
     * @stability stable
     */
    get textAlign(): string;
    /**
     * @stability stable
     */
    set textAlign(value: string);
    /**
     * @stability stable
     */
    resetTextAlign(): void;
    /**
     * @stability stable
     */
    get textAlignInput(): string | undefined;
    private _tickEdge?;
    /**
     * @stability stable
     */
    get tickEdge(): string;
    /**
     * @stability stable
     */
    set tickEdge(value: string);
    /**
     * @stability stable
     */
    resetTickEdge(): void;
    /**
     * @stability stable
     */
    get tickEdgeInput(): string | undefined;
    private _tickPos?;
    /**
     * @stability stable
     */
    get tickPos(): string;
    /**
     * @stability stable
     */
    set tickPos(value: string);
    /**
     * @stability stable
     */
    resetTickPos(): void;
    /**
     * @stability stable
     */
    get tickPosInput(): string | undefined;
    private _verticalAlign?;
    /**
     * @stability stable
     */
    get verticalAlign(): string;
    /**
     * @stability stable
     */
    set verticalAlign(value: string);
    /**
     * @stability stable
     */
    resetVerticalAlign(): void;
    /**
     * @stability stable
     */
    get verticalAlignInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionCustomLinkToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionCustomLink): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryColumns {
    /**
     * A user-assigned alias for the column.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * The column name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryColumnsToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryColumns): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQuery {
    /**
     * The environment name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * The operation name associated with the service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The organization's host group name and value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag Dashboard#primary_tag}
     *
     * @stability stable
     */
    readonly primaryTag: string;
    /**
     * The resource name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#resource Dashboard#resource}
     *
     * @stability stable
     */
    readonly resource?: string;
    /**
     * The level of detail for the request. Valid values are `service`, `resource`, `span`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#row_type Dashboard#row_type}
     *
     * @stability stable
     */
    readonly rowType: string;
    /**
     * The service name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * columns block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#columns Dashboard#columns}
     *
     * @stability stable
     */
    readonly columns?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryColumns[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQuery | undefined);
    private _env?;
    /**
     * @stability stable
     */
    get env(): string;
    /**
     * @stability stable
     */
    set env(value: string);
    /**
     * @stability stable
     */
    get envInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _primaryTag?;
    /**
     * @stability stable
     */
    get primaryTag(): string;
    /**
     * @stability stable
     */
    set primaryTag(value: string);
    /**
     * @stability stable
     */
    get primaryTagInput(): string | undefined;
    private _resource?;
    /**
     * @stability stable
     */
    get resource(): string;
    /**
     * @stability stable
     */
    set resource(value: string);
    /**
     * @stability stable
     */
    resetResource(): void;
    /**
     * @stability stable
     */
    get resourceInput(): string | undefined;
    private _rowType?;
    /**
     * @stability stable
     */
    get rowType(): string;
    /**
     * @stability stable
     */
    set rowType(value: string);
    /**
     * @stability stable
     */
    get rowTypeInput(): string | undefined;
    private _service?;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string | undefined;
    private _columns?;
    /**
     * @stability stable
     */
    get columns(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryColumns[];
    /**
     * @stability stable
     */
    set columns(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryColumns[]);
    /**
     * @stability stable
     */
    resetColumns(): void;
    /**
     * @stability stable
     */
    get columnsInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQueryColumns[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestConditionalFormatsToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestConditionalFormats): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaConditionalFormatsToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaConditionalFormats): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaLimitToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaLimitOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaLimit): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaLimitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaLimit | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaLimit | undefined);
    private _count?;
    /**
     * @stability stable
     */
    get count(): number;
    /**
     * @stability stable
     */
    set count(value: number);
    /**
     * @stability stable
     */
    resetCount(): void;
    /**
     * @stability stable
     */
    get countInput(): number | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    resetOrder(): void;
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaLimit;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormulaToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormula): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestProcessQuery | undefined);
    private _filterBy?;
    /**
     * @stability stable
     */
    get filterBy(): string[];
    /**
     * @stability stable
     */
    set filterBy(value: string[]);
    /**
     * @stability stable
     */
    resetFilterBy(): void;
    /**
     * @stability stable
     */
    get filterByInput(): string[] | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _searchBy?;
    /**
     * @stability stable
     */
    get searchBy(): string;
    /**
     * @stability stable
     */
    set searchBy(value: string);
    /**
     * @stability stable
     */
    resetSearchBy(): void;
    /**
     * @stability stable
     */
    get searchByInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery {
    /**
     * The data source for APM Dependency Stats queries. Valid values are `apm_dependency_stats`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * APM Environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * Determines whether stats for upstream or downstream dependencies should be queried.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_upstream Dashboard#is_upstream}
     *
     * @stability stable
     */
    readonly isUpstream?: boolean | cdktf.IResolvable;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Name of operation on service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#operation_name Dashboard#operation_name}
     *
     * @stability stable
     */
    readonly operationName: string;
    /**
     * The name of the second primary tag used within APM; required when `primary_tag_value` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_name Dashboard#primary_tag_name}
     *
     * @stability stable
     */
    readonly primaryTagName?: string;
    /**
     * Filter APM data by the second primary tag. `primary_tag_name` must also be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_value Dashboard#primary_tag_value}
     *
     * @stability stable
     */
    readonly primaryTagValue?: string;
    /**
     * APM resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#resource_name Dashboard#resource_name}
     *
     * @stability stable
     */
    readonly resourceName: string;
    /**
     * APM service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * APM statistic. Valid values are `avg_duration`, `avg_root_duration`, `avg_spans_per_trace`, `error_rate`, `pct_exec_time`, `pct_of_traces`, `total_traces_count`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#stat Dashboard#stat}
     *
     * @stability stable
     */
    readonly stat: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _env?;
    /**
     * @stability stable
     */
    get env(): string;
    /**
     * @stability stable
     */
    set env(value: string);
    /**
     * @stability stable
     */
    get envInput(): string | undefined;
    private _isUpstream?;
    /**
     * @stability stable
     */
    get isUpstream(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isUpstream(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsUpstream(): void;
    /**
     * @stability stable
     */
    get isUpstreamInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _operationName?;
    /**
     * @stability stable
     */
    get operationName(): string;
    /**
     * @stability stable
     */
    set operationName(value: string);
    /**
     * @stability stable
     */
    get operationNameInput(): string | undefined;
    private _primaryTagName?;
    /**
     * @stability stable
     */
    get primaryTagName(): string;
    /**
     * @stability stable
     */
    set primaryTagName(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagName(): void;
    /**
     * @stability stable
     */
    get primaryTagNameInput(): string | undefined;
    private _primaryTagValue?;
    /**
     * @stability stable
     */
    get primaryTagValue(): string;
    /**
     * @stability stable
     */
    set primaryTagValue(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagValue(): void;
    /**
     * @stability stable
     */
    get primaryTagValueInput(): string | undefined;
    private _resourceName?;
    /**
     * @stability stable
     */
    get resourceName(): string;
    /**
     * @stability stable
     */
    set resourceName(value: string);
    /**
     * @stability stable
     */
    get resourceNameInput(): string | undefined;
    private _service?;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string | undefined;
    private _stat?;
    /**
     * @stability stable
     */
    get stat(): string;
    /**
     * @stability stable
     */
    set stat(value: string);
    /**
     * @stability stable
     */
    get statInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery {
    /**
     * The data source for APM Resource Stats queries. Valid values are `apm_resource_stats`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * APM Environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * Array of fields to group results by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Name of operation on service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#operation_name Dashboard#operation_name}
     *
     * @stability stable
     */
    readonly operationName?: string;
    /**
     * The name of the second primary tag used within APM; required when `primary_tag_value` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_name Dashboard#primary_tag_name}
     *
     * @stability stable
     */
    readonly primaryTagName?: string;
    /**
     * Filter APM data by the second primary tag. `primary_tag_name` must also be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_value Dashboard#primary_tag_value}
     *
     * @stability stable
     */
    readonly primaryTagValue?: string;
    /**
     * APM resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#resource_name Dashboard#resource_name}
     *
     * @stability stable
     */
    readonly resourceName?: string;
    /**
     * APM service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * APM statistic. Valid values are `errors`, `error_rate`, `hits`, `latency_avg`, `latency_max`, `latency_p50`, `latency_p75`, `latency_p90`, `latency_p95`, `latency_p99`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#stat Dashboard#stat}
     *
     * @stability stable
     */
    readonly stat: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmResourceStatsQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmResourceStatsQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmResourceStatsQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _env?;
    /**
     * @stability stable
     */
    get env(): string;
    /**
     * @stability stable
     */
    set env(value: string);
    /**
     * @stability stable
     */
    get envInput(): string | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): string[];
    /**
     * @stability stable
     */
    set groupBy(value: string[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _operationName?;
    /**
     * @stability stable
     */
    get operationName(): string;
    /**
     * @stability stable
     */
    set operationName(value: string);
    /**
     * @stability stable
     */
    resetOperationName(): void;
    /**
     * @stability stable
     */
    get operationNameInput(): string | undefined;
    private _primaryTagName?;
    /**
     * @stability stable
     */
    get primaryTagName(): string;
    /**
     * @stability stable
     */
    set primaryTagName(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagName(): void;
    /**
     * @stability stable
     */
    get primaryTagNameInput(): string | undefined;
    private _primaryTagValue?;
    /**
     * @stability stable
     */
    get primaryTagValue(): string;
    /**
     * @stability stable
     */
    set primaryTagValue(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagValue(): void;
    /**
     * @stability stable
     */
    get primaryTagValueInput(): string | undefined;
    private _resourceName?;
    /**
     * @stability stable
     */
    get resourceName(): string;
    /**
     * @stability stable
     */
    set resourceName(value: string);
    /**
     * @stability stable
     */
    resetResourceName(): void;
    /**
     * @stability stable
     */
    get resourceNameInput(): string | undefined;
    private _service?;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string | undefined;
    private _stat?;
    /**
     * @stability stable
     */
    get stat(): string;
    /**
     * @stability stable
     */
    set stat(value: string);
    /**
     * @stability stable
     */
    get statInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySortToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySortOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySortOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    resetMetric(): void;
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    resetOrder(): void;
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBySort;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearchToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearchOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearch): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearch | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearch | undefined);
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearch;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _indexes?;
    /**
     * @stability stable
     */
    get indexes(): string[];
    /**
     * @stability stable
     */
    set indexes(value: string[]);
    /**
     * @stability stable
     */
    resetIndexes(): void;
    /**
     * @stability stable
     */
    get indexesInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _compute?;
    /**
     * @stability stable
     */
    get compute(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryCompute[];
    /**
     * @stability stable
     */
    set compute(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryCompute[]);
    /**
     * @stability stable
     */
    get computeInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryCompute[] | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQueryGroupBy[] | undefined;
    private _search;
    /**
     * @stability stable
     */
    get search(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearchOutputReference;
    /**
     * @stability stable
     */
    putSearch(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearch): void;
    /**
     * @stability stable
     */
    resetSearch(): void;
    /**
     * @stability stable
     */
    get searchInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuerySearch | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryMetricQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryMetricQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryMetricQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryMetricQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryMetricQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryMetricQuery | undefined);
    private _aggregator?;
    /**
     * @stability stable
     */
    get aggregator(): string;
    /**
     * @stability stable
     */
    set aggregator(value: string);
    /**
     * @stability stable
     */
    resetAggregator(): void;
    /**
     * @stability stable
     */
    get aggregatorInput(): string | undefined;
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    resetDataSource(): void;
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryProcessQuery | undefined);
    private _aggregator?;
    /**
     * @stability stable
     */
    get aggregator(): string;
    /**
     * @stability stable
     */
    set aggregator(value: string);
    /**
     * @stability stable
     */
    resetAggregator(): void;
    /**
     * @stability stable
     */
    get aggregatorInput(): string | undefined;
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _isNormalizedCpu?;
    /**
     * @stability stable
     */
    get isNormalizedCpu(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isNormalizedCpu(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsNormalizedCpu(): void;
    /**
     * @stability stable
     */
    get isNormalizedCpuInput(): boolean | cdktf.IResolvable | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _sort?;
    /**
     * @stability stable
     */
    get sort(): string;
    /**
     * @stability stable
     */
    set sort(value: string);
    /**
     * @stability stable
     */
    resetSort(): void;
    /**
     * @stability stable
     */
    get sortInput(): string | undefined;
    private _tagFilters?;
    /**
     * @stability stable
     */
    get tagFilters(): string[];
    /**
     * @stability stable
     */
    set tagFilters(value: string[]);
    /**
     * @stability stable
     */
    resetTagFilters(): void;
    /**
     * @stability stable
     */
    get tagFiltersInput(): string[] | undefined;
    private _textFilter?;
    /**
     * @stability stable
     */
    get textFilter(): string;
    /**
     * @stability stable
     */
    set textFilter(value: string);
    /**
     * @stability stable
     */
    resetTextFilter(): void;
    /**
     * @stability stable
     */
    get textFilterInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQuery {
    /**
     * apm_dependency_stats_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_dependency_stats_query Dashboard#apm_dependency_stats_query}
     *
     * @stability stable
     */
    readonly apmDependencyStatsQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmDependencyStatsQuery;
    /**
     * apm_resource_stats_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_resource_stats_query Dashboard#apm_resource_stats_query}
     *
     * @stability stable
     */
    readonly apmResourceStatsQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryApmResourceStatsQuery;
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryEventQuery;
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryMetricQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryProcessQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQuery): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequest {
    /**
     * The aggregator to use for time aggregation. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The alias for the column name (defaults to metric name).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell.
     *
     * List items one of `number`, `bar`. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string[];
    /**
     * The number of lines to show in the table.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The sort order for the rows. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmQuery;
    /**
     * apm_stats_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_stats_query Dashboard#apm_stats_query}
     *
     * @stability stable
     */
    readonly apmStatsQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestApmStatsQuery;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestConditionalFormats[];
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestLogQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestProcessQuery;
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestRumQuery;
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestSecurityQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequestToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequest): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryTableDefinition {
    /**
     * Controls the display of the search bar. Valid values are `always`, `never`, `auto`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#has_search_bar Dashboard#has_search_bar}
     *
     * @stability stable
     */
    readonly hasSearchBar?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequest[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryTableDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetQueryTableDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinition | undefined);
    private _hasSearchBar?;
    /**
     * @stability stable
     */
    get hasSearchBar(): string;
    /**
     * @stability stable
     */
    set hasSearchBar(value: string);
    /**
     * @stability stable
     */
    resetHasSearchBar(): void;
    /**
     * @stability stable
     */
    get hasSearchBarInput(): string | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _customLink?;
    /**
     * @stability stable
     */
    get customLink(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionCustomLink[];
    /**
     * @stability stable
     */
    set customLink(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionCustomLink[]);
    /**
     * @stability stable
     */
    resetCustomLink(): void;
    /**
     * @stability stable
     */
    get customLinkInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionCustomLink[] | undefined;
    private _request?;
    /**
     * @stability stable
     */
    get request(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequest[];
    /**
     * @stability stable
     */
    set request(value: DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequest[]);
    /**
     * @stability stable
     */
    resetRequest(): void;
    /**
     * @stability stable
     */
    get requestInput(): DashboardWidgetGroupDefinitionWidgetQueryTableDefinitionRequest[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionCustomLinkToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionCustomLink): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestConditionalFormatsToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestConditionalFormats): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaConditionalFormatsToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaConditionalFormats): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaLimitToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaLimitOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaLimit): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaLimitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaLimit | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaLimit | undefined);
    private _count?;
    /**
     * @stability stable
     */
    get count(): number;
    /**
     * @stability stable
     */
    set count(value: number);
    /**
     * @stability stable
     */
    resetCount(): void;
    /**
     * @stability stable
     */
    get countInput(): number | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    resetOrder(): void;
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaLimit;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormulaToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormula): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestProcessQuery | undefined);
    private _filterBy?;
    /**
     * @stability stable
     */
    get filterBy(): string[];
    /**
     * @stability stable
     */
    set filterBy(value: string[]);
    /**
     * @stability stable
     */
    resetFilterBy(): void;
    /**
     * @stability stable
     */
    get filterByInput(): string[] | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _searchBy?;
    /**
     * @stability stable
     */
    get searchBy(): string;
    /**
     * @stability stable
     */
    set searchBy(value: string);
    /**
     * @stability stable
     */
    resetSearchBy(): void;
    /**
     * @stability stable
     */
    get searchByInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery {
    /**
     * The data source for APM Dependency Stats queries. Valid values are `apm_dependency_stats`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * APM Environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * Determines whether stats for upstream or downstream dependencies should be queried.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_upstream Dashboard#is_upstream}
     *
     * @stability stable
     */
    readonly isUpstream?: boolean | cdktf.IResolvable;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Name of operation on service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#operation_name Dashboard#operation_name}
     *
     * @stability stable
     */
    readonly operationName: string;
    /**
     * The name of the second primary tag used within APM; required when `primary_tag_value` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_name Dashboard#primary_tag_name}
     *
     * @stability stable
     */
    readonly primaryTagName?: string;
    /**
     * Filter APM data by the second primary tag. `primary_tag_name` must also be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_value Dashboard#primary_tag_value}
     *
     * @stability stable
     */
    readonly primaryTagValue?: string;
    /**
     * APM resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#resource_name Dashboard#resource_name}
     *
     * @stability stable
     */
    readonly resourceName: string;
    /**
     * APM service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * APM statistic. Valid values are `avg_duration`, `avg_root_duration`, `avg_spans_per_trace`, `error_rate`, `pct_exec_time`, `pct_of_traces`, `total_traces_count`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#stat Dashboard#stat}
     *
     * @stability stable
     */
    readonly stat: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _env?;
    /**
     * @stability stable
     */
    get env(): string;
    /**
     * @stability stable
     */
    set env(value: string);
    /**
     * @stability stable
     */
    get envInput(): string | undefined;
    private _isUpstream?;
    /**
     * @stability stable
     */
    get isUpstream(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isUpstream(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsUpstream(): void;
    /**
     * @stability stable
     */
    get isUpstreamInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _operationName?;
    /**
     * @stability stable
     */
    get operationName(): string;
    /**
     * @stability stable
     */
    set operationName(value: string);
    /**
     * @stability stable
     */
    get operationNameInput(): string | undefined;
    private _primaryTagName?;
    /**
     * @stability stable
     */
    get primaryTagName(): string;
    /**
     * @stability stable
     */
    set primaryTagName(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagName(): void;
    /**
     * @stability stable
     */
    get primaryTagNameInput(): string | undefined;
    private _primaryTagValue?;
    /**
     * @stability stable
     */
    get primaryTagValue(): string;
    /**
     * @stability stable
     */
    set primaryTagValue(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagValue(): void;
    /**
     * @stability stable
     */
    get primaryTagValueInput(): string | undefined;
    private _resourceName?;
    /**
     * @stability stable
     */
    get resourceName(): string;
    /**
     * @stability stable
     */
    set resourceName(value: string);
    /**
     * @stability stable
     */
    get resourceNameInput(): string | undefined;
    private _service?;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string | undefined;
    private _stat?;
    /**
     * @stability stable
     */
    get stat(): string;
    /**
     * @stability stable
     */
    set stat(value: string);
    /**
     * @stability stable
     */
    get statInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery {
    /**
     * The data source for APM Resource Stats queries. Valid values are `apm_resource_stats`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * APM Environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#env Dashboard#env}
     *
     * @stability stable
     */
    readonly env: string;
    /**
     * Array of fields to group results by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Name of operation on service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#operation_name Dashboard#operation_name}
     *
     * @stability stable
     */
    readonly operationName?: string;
    /**
     * The name of the second primary tag used within APM; required when `primary_tag_value` is specified. See https://docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_name Dashboard#primary_tag_name}
     *
     * @stability stable
     */
    readonly primaryTagName?: string;
    /**
     * Filter APM data by the second primary tag. `primary_tag_name` must also be specified.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#primary_tag_value Dashboard#primary_tag_value}
     *
     * @stability stable
     */
    readonly primaryTagValue?: string;
    /**
     * APM resource.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#resource_name Dashboard#resource_name}
     *
     * @stability stable
     */
    readonly resourceName?: string;
    /**
     * APM service.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * APM statistic. Valid values are `errors`, `error_rate`, `hits`, `latency_avg`, `latency_max`, `latency_p50`, `latency_p75`, `latency_p90`, `latency_p95`, `latency_p99`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#stat Dashboard#stat}
     *
     * @stability stable
     */
    readonly stat: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmResourceStatsQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmResourceStatsQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmResourceStatsQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _env?;
    /**
     * @stability stable
     */
    get env(): string;
    /**
     * @stability stable
     */
    set env(value: string);
    /**
     * @stability stable
     */
    get envInput(): string | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): string[];
    /**
     * @stability stable
     */
    set groupBy(value: string[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _operationName?;
    /**
     * @stability stable
     */
    get operationName(): string;
    /**
     * @stability stable
     */
    set operationName(value: string);
    /**
     * @stability stable
     */
    resetOperationName(): void;
    /**
     * @stability stable
     */
    get operationNameInput(): string | undefined;
    private _primaryTagName?;
    /**
     * @stability stable
     */
    get primaryTagName(): string;
    /**
     * @stability stable
     */
    set primaryTagName(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagName(): void;
    /**
     * @stability stable
     */
    get primaryTagNameInput(): string | undefined;
    private _primaryTagValue?;
    /**
     * @stability stable
     */
    get primaryTagValue(): string;
    /**
     * @stability stable
     */
    set primaryTagValue(value: string);
    /**
     * @stability stable
     */
    resetPrimaryTagValue(): void;
    /**
     * @stability stable
     */
    get primaryTagValueInput(): string | undefined;
    private _resourceName?;
    /**
     * @stability stable
     */
    get resourceName(): string;
    /**
     * @stability stable
     */
    set resourceName(value: string);
    /**
     * @stability stable
     */
    resetResourceName(): void;
    /**
     * @stability stable
     */
    get resourceNameInput(): string | undefined;
    private _service?;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string | undefined;
    private _stat?;
    /**
     * @stability stable
     */
    get stat(): string;
    /**
     * @stability stable
     */
    set stat(value: string);
    /**
     * @stability stable
     */
    get statInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryCompute {
    /**
     * The aggregation methods for event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * A time interval in milliseconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
    /**
     * The measurable attribute to compute.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort {
    /**
     * The aggregation methods for the event platform queries.
     *
     * Valid values are `count`, `cardinality`, `median`, `pc75`, `pc90`, `pc95`, `pc98`, `pc99`, `sum`, `min`, `max`, `avg`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The metric used for sorting group by results.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * Direction of sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySortToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySortOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySortOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    resetMetric(): void;
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    resetOrder(): void;
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy {
    /**
     * The event facet.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet: string;
    /**
     * The number of groups to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBySort;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearch {
    /**
     * The events search string.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearchToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearchOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearch): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearchOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearch | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearch | undefined);
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuery {
    /**
     * The data source for event platform-based queries. Valid values are `logs`, `spans`, `network`, `rum`, `security_signals`, `profiles`, `audit`, `events`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * An array of index names to query in the stream.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#indexes Dashboard#indexes}
     *
     * @stability stable
     */
    readonly indexes?: string[];
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute Dashboard#compute}
     *
     * @stability stable
     */
    readonly compute: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryCompute[];
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * search block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search Dashboard#search}
     *
     * @stability stable
     */
    readonly search?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearch;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuery | undefined);
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _indexes?;
    /**
     * @stability stable
     */
    get indexes(): string[];
    /**
     * @stability stable
     */
    set indexes(value: string[]);
    /**
     * @stability stable
     */
    resetIndexes(): void;
    /**
     * @stability stable
     */
    get indexesInput(): string[] | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _compute?;
    /**
     * @stability stable
     */
    get compute(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryCompute[];
    /**
     * @stability stable
     */
    set compute(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryCompute[]);
    /**
     * @stability stable
     */
    get computeInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryCompute[] | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQueryGroupBy[] | undefined;
    private _search;
    /**
     * @stability stable
     */
    get search(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearchOutputReference;
    /**
     * @stability stable
     */
    putSearch(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearch): void;
    /**
     * @stability stable
     */
    resetSearch(): void;
    /**
     * @stability stable
     */
    get searchInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuerySearch | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryMetricQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for metrics queries.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource?: string;
    /**
     * The name of the query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The metrics query definition.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryMetricQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryMetricQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryMetricQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryMetricQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryMetricQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryMetricQuery | undefined);
    private _aggregator?;
    /**
     * @stability stable
     */
    get aggregator(): string;
    /**
     * @stability stable
     */
    set aggregator(value: string);
    /**
     * @stability stable
     */
    resetAggregator(): void;
    /**
     * @stability stable
     */
    get aggregatorInput(): string | undefined;
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    resetDataSource(): void;
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _query?;
    /**
     * @stability stable
     */
    get query(): string;
    /**
     * @stability stable
     */
    set query(value: string);
    /**
     * @stability stable
     */
    get queryInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryProcessQuery {
    /**
     * The aggregation methods available for metrics queries. Valid values are `avg`, `min`, `max`, `sum`, `last`, `area`, `l2norm`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The data source for process queries. Valid values are `process`, `container`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#data_source Dashboard#data_source}
     *
     * @stability stable
     */
    readonly dataSource: string;
    /**
     * Whether to normalize the CPU percentages.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_normalized_cpu Dashboard#is_normalized_cpu}
     *
     * @stability stable
     */
    readonly isNormalizedCpu?: boolean | cdktf.IResolvable;
    /**
     * The number of hits to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * The process metric name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * The name of query for use in formulas.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#name Dashboard#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort Dashboard#sort}
     *
     * @stability stable
     */
    readonly sort?: string;
    /**
     * An array of tags to filter by.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tag_filters Dashboard#tag_filters}
     *
     * @stability stable
     */
    readonly tagFilters?: string[];
    /**
     * The text to use as a filter.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_filter Dashboard#text_filter}
     *
     * @stability stable
     */
    readonly textFilter?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryProcessQuery | undefined);
    private _aggregator?;
    /**
     * @stability stable
     */
    get aggregator(): string;
    /**
     * @stability stable
     */
    set aggregator(value: string);
    /**
     * @stability stable
     */
    resetAggregator(): void;
    /**
     * @stability stable
     */
    get aggregatorInput(): string | undefined;
    private _dataSource?;
    /**
     * @stability stable
     */
    get dataSource(): string;
    /**
     * @stability stable
     */
    set dataSource(value: string);
    /**
     * @stability stable
     */
    get dataSourceInput(): string | undefined;
    private _isNormalizedCpu?;
    /**
     * @stability stable
     */
    get isNormalizedCpu(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set isNormalizedCpu(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIsNormalizedCpu(): void;
    /**
     * @stability stable
     */
    get isNormalizedCpuInput(): boolean | cdktf.IResolvable | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _sort?;
    /**
     * @stability stable
     */
    get sort(): string;
    /**
     * @stability stable
     */
    set sort(value: string);
    /**
     * @stability stable
     */
    resetSort(): void;
    /**
     * @stability stable
     */
    get sortInput(): string | undefined;
    private _tagFilters?;
    /**
     * @stability stable
     */
    get tagFilters(): string[];
    /**
     * @stability stable
     */
    set tagFilters(value: string[]);
    /**
     * @stability stable
     */
    resetTagFilters(): void;
    /**
     * @stability stable
     */
    get tagFiltersInput(): string[] | undefined;
    private _textFilter?;
    /**
     * @stability stable
     */
    get textFilter(): string;
    /**
     * @stability stable
     */
    set textFilter(value: string);
    /**
     * @stability stable
     */
    resetTextFilter(): void;
    /**
     * @stability stable
     */
    get textFilterInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQuery {
    /**
     * apm_dependency_stats_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_dependency_stats_query Dashboard#apm_dependency_stats_query}
     *
     * @stability stable
     */
    readonly apmDependencyStatsQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmDependencyStatsQuery;
    /**
     * apm_resource_stats_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_resource_stats_query Dashboard#apm_resource_stats_query}
     *
     * @stability stable
     */
    readonly apmResourceStatsQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryApmResourceStatsQuery;
    /**
     * event_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#event_query Dashboard#event_query}
     *
     * @stability stable
     */
    readonly eventQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryEventQuery;
    /**
     * metric_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric_query Dashboard#metric_query}
     *
     * @stability stable
     */
    readonly metricQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryMetricQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryProcessQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQuery): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequest {
    /**
     * The aggregator to use for time aggregation. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestApmQuery;
    /**
     * audit_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#audit_query Dashboard#audit_query}
     *
     * @stability stable
     */
    readonly auditQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestAuditQuery;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestConditionalFormats[];
    /**
     * formula block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula Dashboard#formula}
     *
     * @stability stable
     */
    readonly formula?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestFormula[];
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestLogQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestProcessQuery;
    /**
     * query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#query Dashboard#query}
     *
     * @stability stable
     */
    readonly query?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestQuery[];
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestRumQuery;
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestSecurityQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequestToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequest): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetQueryValueDefinition {
    /**
     * A Boolean indicating whether to automatically scale the tile.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#autoscale Dashboard#autoscale}
     *
     * @stability stable
     */
    readonly autoscale?: boolean | cdktf.IResolvable;
    /**
     * The unit for the value displayed in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_unit Dashboard#custom_unit}
     *
     * @stability stable
     */
    readonly customUnit?: string;
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The precision to use when displaying the tile.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#precision Dashboard#precision}
     *
     * @stability stable
     */
    readonly precision?: number;
    /**
     * The alignment of the widget's text. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#text_align Dashboard#text_align}
     *
     * @stability stable
     */
    readonly textAlign?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequest[];
}
export declare function dashboardWidgetGroupDefinitionWidgetQueryValueDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetQueryValueDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinition | undefined);
    private _autoscale?;
    /**
     * @stability stable
     */
    get autoscale(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set autoscale(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetAutoscale(): void;
    /**
     * @stability stable
     */
    get autoscaleInput(): boolean | cdktf.IResolvable | undefined;
    private _customUnit?;
    /**
     * @stability stable
     */
    get customUnit(): string;
    /**
     * @stability stable
     */
    set customUnit(value: string);
    /**
     * @stability stable
     */
    resetCustomUnit(): void;
    /**
     * @stability stable
     */
    get customUnitInput(): string | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _precision?;
    /**
     * @stability stable
     */
    get precision(): number;
    /**
     * @stability stable
     */
    set precision(value: number);
    /**
     * @stability stable
     */
    resetPrecision(): void;
    /**
     * @stability stable
     */
    get precisionInput(): number | undefined;
    private _textAlign?;
    /**
     * @stability stable
     */
    get textAlign(): string;
    /**
     * @stability stable
     */
    set textAlign(value: string);
    /**
     * @stability stable
     */
    resetTextAlign(): void;
    /**
     * @stability stable
     */
    get textAlignInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _customLink?;
    /**
     * @stability stable
     */
    get customLink(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionCustomLink[];
    /**
     * @stability stable
     */
    set customLink(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionCustomLink[]);
    /**
     * @stability stable
     */
    resetCustomLink(): void;
    /**
     * @stability stable
     */
    get customLinkInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionCustomLink[] | undefined;
    private _request?;
    /**
     * @stability stable
     */
    get request(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequest[];
    /**
     * @stability stable
     */
    set request(value: DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequest[]);
    /**
     * @stability stable
     */
    resetRequest(): void;
    /**
     * @stability stable
     */
    get requestInput(): DashboardWidgetGroupDefinitionWidgetQueryValueDefinitionRequest[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionCustomLinkToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionCustomLink): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXProcessQuery | undefined);
    private _filterBy?;
    /**
     * @stability stable
     */
    get filterBy(): string[];
    /**
     * @stability stable
     */
    set filterBy(value: string[]);
    /**
     * @stability stable
     */
    resetFilterBy(): void;
    /**
     * @stability stable
     */
    get filterByInput(): string[] | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _searchBy?;
    /**
     * @stability stable
     */
    get searchBy(): string;
    /**
     * @stability stable
     */
    set searchBy(value: string);
    /**
     * @stability stable
     */
    resetSearchBy(): void;
    /**
     * @stability stable
     */
    get searchByInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestX {
    /**
     * Aggregator used for the request. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXApmQuery;
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXLogQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXProcessQuery;
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXRumQuery;
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXSecurityQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestXToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestX): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYProcessQuery {
    /**
     * A list of processes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filter_by Dashboard#filter_by}
     *
     * @stability stable
     */
    readonly filterBy?: string[];
    /**
     * The max number of items in the filter list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * Your chosen metric.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric: string;
    /**
     * Your chosen search term.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_by Dashboard#search_by}
     *
     * @stability stable
     */
    readonly searchBy?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYProcessQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYProcessQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYProcessQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYProcessQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYProcessQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYProcessQuery | undefined);
    private _filterBy?;
    /**
     * @stability stable
     */
    get filterBy(): string[];
    /**
     * @stability stable
     */
    set filterBy(value: string[]);
    /**
     * @stability stable
     */
    resetFilterBy(): void;
    /**
     * @stability stable
     */
    get filterByInput(): string[] | undefined;
    private _limit?;
    /**
     * @stability stable
     */
    get limit(): number;
    /**
     * @stability stable
     */
    set limit(value: number);
    /**
     * @stability stable
     */
    resetLimit(): void;
    /**
     * @stability stable
     */
    get limitInput(): number | undefined;
    private _metric?;
    /**
     * @stability stable
     */
    get metric(): string;
    /**
     * @stability stable
     */
    set metric(value: string);
    /**
     * @stability stable
     */
    get metricInput(): string | undefined;
    private _searchBy?;
    /**
     * @stability stable
     */
    get searchBy(): string;
    /**
     * @stability stable
     */
    set searchBy(value: string);
    /**
     * @stability stable
     */
    resetSearchBy(): void;
    /**
     * @stability stable
     */
    get searchByInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestY {
    /**
     * Aggregator used for the request. Valid values are `avg`, `last`, `max`, `min`, `sum`, `percentile`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregator Dashboard#aggregator}
     *
     * @stability stable
     */
    readonly aggregator?: string;
    /**
     * The metric query to use for this widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q?: string;
    /**
     * apm_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#apm_query Dashboard#apm_query}
     *
     * @stability stable
     */
    readonly apmQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYApmQuery;
    /**
     * log_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#log_query Dashboard#log_query}
     *
     * @stability stable
     */
    readonly logQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYLogQuery;
    /**
     * process_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#process_query Dashboard#process_query}
     *
     * @stability stable
     */
    readonly processQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYProcessQuery;
    /**
     * rum_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#rum_query Dashboard#rum_query}
     *
     * @stability stable
     */
    readonly rumQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYRumQuery;
    /**
     * security_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#security_query Dashboard#security_query}
     *
     * @stability stable
     */
    readonly securityQuery?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYSecurityQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestYToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestY): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequest {
    /**
     * x block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#x Dashboard#x}
     *
     * @stability stable
     */
    readonly x?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestX[];
    /**
     * y block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#y Dashboard#y}
     *
     * @stability stable
     */
    readonly y?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestY[];
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequest): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequest | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequest | undefined);
    private _x?;
    /**
     * @stability stable
     */
    get x(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestX[];
    /**
     * @stability stable
     */
    set x(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestX[]);
    /**
     * @stability stable
     */
    resetX(): void;
    /**
     * @stability stable
     */
    get xInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestX[] | undefined;
    private _y?;
    /**
     * @stability stable
     */
    get y(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestY[];
    /**
     * @stability stable
     */
    set y(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestY[]);
    /**
     * @stability stable
     */
    resetY(): void;
    /**
     * @stability stable
     */
    get yInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestY[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxisToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxisOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxis): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxisOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxis | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxis | undefined);
    private _includeZero?;
    /**
     * @stability stable
     */
    get includeZero(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set includeZero(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIncludeZero(): void;
    /**
     * @stability stable
     */
    get includeZeroInput(): boolean | cdktf.IResolvable | undefined;
    private _label?;
    /**
     * @stability stable
     */
    get label(): string;
    /**
     * @stability stable
     */
    set label(value: string);
    /**
     * @stability stable
     */
    resetLabel(): void;
    /**
     * @stability stable
     */
    get labelInput(): string | undefined;
    private _max?;
    /**
     * @stability stable
     */
    get max(): string;
    /**
     * @stability stable
     */
    set max(value: string);
    /**
     * @stability stable
     */
    resetMax(): void;
    /**
     * @stability stable
     */
    get maxInput(): string | undefined;
    private _min?;
    /**
     * @stability stable
     */
    get min(): string;
    /**
     * @stability stable
     */
    set min(value: string);
    /**
     * @stability stable
     */
    resetMin(): void;
    /**
     * @stability stable
     */
    get minInput(): string | undefined;
    private _scale?;
    /**
     * @stability stable
     */
    get scale(): string;
    /**
     * @stability stable
     */
    set scale(value: string);
    /**
     * @stability stable
     */
    resetScale(): void;
    /**
     * @stability stable
     */
    get scaleInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxis {
    /**
     * Always include zero or fit the axis to the data range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#include_zero Dashboard#include_zero}
     *
     * @stability stable
     */
    readonly includeZero?: boolean | cdktf.IResolvable;
    /**
     * The label of the axis to display on the graph.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * Specify the maximum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#max Dashboard#max}
     *
     * @stability stable
     */
    readonly max?: string;
    /**
     * Specify the minimum value to show on the Y-axis.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#min Dashboard#min}
     *
     * @stability stable
     */
    readonly min?: string;
    /**
     * Specify the scale type, options: `linear`, `log`, `pow`, `sqrt`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#scale Dashboard#scale}
     *
     * @stability stable
     */
    readonly scale?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxisToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxisOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxis): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxisOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxis | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxis | undefined);
    private _includeZero?;
    /**
     * @stability stable
     */
    get includeZero(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set includeZero(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIncludeZero(): void;
    /**
     * @stability stable
     */
    get includeZeroInput(): boolean | cdktf.IResolvable | undefined;
    private _label?;
    /**
     * @stability stable
     */
    get label(): string;
    /**
     * @stability stable
     */
    set label(value: string);
    /**
     * @stability stable
     */
    resetLabel(): void;
    /**
     * @stability stable
     */
    get labelInput(): string | undefined;
    private _max?;
    /**
     * @stability stable
     */
    get max(): string;
    /**
     * @stability stable
     */
    set max(value: string);
    /**
     * @stability stable
     */
    resetMax(): void;
    /**
     * @stability stable
     */
    get maxInput(): string | undefined;
    private _min?;
    /**
     * @stability stable
     */
    get min(): string;
    /**
     * @stability stable
     */
    set min(value: string);
    /**
     * @stability stable
     */
    resetMin(): void;
    /**
     * @stability stable
     */
    get minInput(): string | undefined;
    private _scale?;
    /**
     * @stability stable
     */
    get scale(): string;
    /**
     * @stability stable
     */
    set scale(value: string);
    /**
     * @stability stable
     */
    resetScale(): void;
    /**
     * @stability stable
     */
    get scaleInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetScatterplotDefinition {
    /**
     * List of groups used for colors.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#color_by_groups Dashboard#color_by_groups}
     *
     * @stability stable
     */
    readonly colorByGroups?: string[];
    /**
     * The timeframe to use when displaying the widget.
     *
     * Valid values are `1m`, `5m`, `10m`, `15m`, `30m`, `1h`, `4h`, `1d`, `2d`, `1w`, `1mo`, `3mo`, `6mo`, `1y`, `alert`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#live_span Dashboard#live_span}
     *
     * @stability stable
     */
    readonly liveSpan?: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionCustomLink[];
    /**
     * request block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#request Dashboard#request}
     *
     * @stability stable
     */
    readonly request?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequest;
    /**
     * xaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#xaxis Dashboard#xaxis}
     *
     * @stability stable
     */
    readonly xaxis?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxis;
    /**
     * yaxis block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#yaxis Dashboard#yaxis}
     *
     * @stability stable
     */
    readonly yaxis?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxis;
}
export declare function dashboardWidgetGroupDefinitionWidgetScatterplotDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetScatterplotDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinition | undefined);
    private _colorByGroups?;
    /**
     * @stability stable
     */
    get colorByGroups(): string[];
    /**
     * @stability stable
     */
    set colorByGroups(value: string[]);
    /**
     * @stability stable
     */
    resetColorByGroups(): void;
    /**
     * @stability stable
     */
    get colorByGroupsInput(): string[] | undefined;
    private _liveSpan?;
    /**
     * @stability stable
     */
    get liveSpan(): string;
    /**
     * @stability stable
     */
    set liveSpan(value: string);
    /**
     * @stability stable
     */
    resetLiveSpan(): void;
    /**
     * @stability stable
     */
    get liveSpanInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _customLink?;
    /**
     * @stability stable
     */
    get customLink(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionCustomLink[];
    /**
     * @stability stable
     */
    set customLink(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionCustomLink[]);
    /**
     * @stability stable
     */
    resetCustomLink(): void;
    /**
     * @stability stable
     */
    get customLinkInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionCustomLink[] | undefined;
    private _request;
    /**
     * @stability stable
     */
    get request(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequestOutputReference;
    /**
     * @stability stable
     */
    putRequest(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequest): void;
    /**
     * @stability stable
     */
    resetRequest(): void;
    /**
     * @stability stable
     */
    get requestInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionRequest | undefined;
    private _xaxis;
    /**
     * @stability stable
     */
    get xaxis(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxisOutputReference;
    /**
     * @stability stable
     */
    putXaxis(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxis): void;
    /**
     * @stability stable
     */
    resetXaxis(): void;
    /**
     * @stability stable
     */
    get xaxisInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionXaxis | undefined;
    private _yaxis;
    /**
     * @stability stable
     */
    get yaxis(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxisOutputReference;
    /**
     * @stability stable
     */
    putYaxis(value: DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxis): void;
    /**
     * @stability stable
     */
    resetYaxis(): void;
    /**
     * @stability stable
     */
    get yaxisInput(): DashboardWidgetGroupDefinitionWidgetScatterplotDefinitionYaxis | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetServiceLevelObjectiveDefinition {
    /**
     * The global time target of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#global_time_target Dashboard#global_time_target}
     *
     * @stability stable
     */
    readonly globalTimeTarget?: string;
    /**
     * Whether to show the error budget or not.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#show_error_budget Dashboard#show_error_budget}
     *
     * @stability stable
     */
    readonly showErrorBudget?: boolean | cdktf.IResolvable;
    /**
     * The ID of the service level objective used by the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#slo_id Dashboard#slo_id}
     *
     * @stability stable
     */
    readonly sloId: string;
    /**
     * A list of time windows to display in the widget.
     *
     * Valid values are `7d`, `30d`, `90d`, `week_to_date`, `previous_week`, `month_to_date`, `previous_month`, `global_time`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#time_windows Dashboard#time_windows}
     *
     * @stability stable
     */
    readonly timeWindows: string[];
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * The view mode for the widget. Valid values are `overall`, `component`, `both`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#view_mode Dashboard#view_mode}
     *
     * @stability stable
     */
    readonly viewMode: string;
    /**
     * The type of view to use when displaying the widget. Only `detail` is supported.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#view_type Dashboard#view_type}
     *
     * @stability stable
     */
    readonly viewType: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetServiceLevelObjectiveDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetServiceLevelObjectiveDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetServiceLevelObjectiveDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetServiceLevelObjectiveDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetServiceLevelObjectiveDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetServiceLevelObjectiveDefinition | undefined);
    private _globalTimeTarget?;
    /**
     * @stability stable
     */
    get globalTimeTarget(): string;
    /**
     * @stability stable
     */
    set globalTimeTarget(value: string);
    /**
     * @stability stable
     */
    resetGlobalTimeTarget(): void;
    /**
     * @stability stable
     */
    get globalTimeTargetInput(): string | undefined;
    private _showErrorBudget?;
    /**
     * @stability stable
     */
    get showErrorBudget(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set showErrorBudget(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetShowErrorBudget(): void;
    /**
     * @stability stable
     */
    get showErrorBudgetInput(): boolean | cdktf.IResolvable | undefined;
    private _sloId?;
    /**
     * @stability stable
     */
    get sloId(): string;
    /**
     * @stability stable
     */
    set sloId(value: string);
    /**
     * @stability stable
     */
    get sloIdInput(): string | undefined;
    private _timeWindows?;
    /**
     * @stability stable
     */
    get timeWindows(): string[];
    /**
     * @stability stable
     */
    set timeWindows(value: string[]);
    /**
     * @stability stable
     */
    get timeWindowsInput(): string[] | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _viewMode?;
    /**
     * @stability stable
     */
    get viewMode(): string;
    /**
     * @stability stable
     */
    set viewMode(value: string);
    /**
     * @stability stable
     */
    get viewModeInput(): string | undefined;
    private _viewType?;
    /**
     * @stability stable
     */
    get viewType(): string;
    /**
     * @stability stable
     */
    set viewType(value: string);
    /**
     * @stability stable
     */
    get viewTypeInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetServicemapDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetServicemapDefinitionCustomLinkToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetServicemapDefinitionCustomLink): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetServicemapDefinition {
    /**
     * Your environment and primary tag (or `*` if enabled for your account).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#filters Dashboard#filters}
     *
     * @stability stable
     */
    readonly filters: string[];
    /**
     * The ID of the service to map.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#service Dashboard#service}
     *
     * @stability stable
     */
    readonly service: string;
    /**
     * The title of the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title Dashboard#title}
     *
     * @stability stable
     */
    readonly title?: string;
    /**
     * The alignment of the widget's title. Valid values are `center`, `left`, `right`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_align Dashboard#title_align}
     *
     * @stability stable
     */
    readonly titleAlign?: string;
    /**
     * The size of the widget's title (defaults to 16).
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#title_size Dashboard#title_size}
     *
     * @stability stable
     */
    readonly titleSize?: string;
    /**
     * custom_link block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_link Dashboard#custom_link}
     *
     * @stability stable
     */
    readonly customLink?: DashboardWidgetGroupDefinitionWidgetServicemapDefinitionCustomLink[];
}
export declare function dashboardWidgetGroupDefinitionWidgetServicemapDefinitionToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetServicemapDefinitionOutputReference | DashboardWidgetGroupDefinitionWidgetServicemapDefinition): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetServicemapDefinitionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetServicemapDefinition | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetServicemapDefinition | undefined);
    private _filters?;
    /**
     * @stability stable
     */
    get filters(): string[];
    /**
     * @stability stable
     */
    set filters(value: string[]);
    /**
     * @stability stable
     */
    get filtersInput(): string[] | undefined;
    private _service?;
    /**
     * @stability stable
     */
    get service(): string;
    /**
     * @stability stable
     */
    set service(value: string);
    /**
     * @stability stable
     */
    get serviceInput(): string | undefined;
    private _title?;
    /**
     * @stability stable
     */
    get title(): string;
    /**
     * @stability stable
     */
    set title(value: string);
    /**
     * @stability stable
     */
    resetTitle(): void;
    /**
     * @stability stable
     */
    get titleInput(): string | undefined;
    private _titleAlign?;
    /**
     * @stability stable
     */
    get titleAlign(): string;
    /**
     * @stability stable
     */
    set titleAlign(value: string);
    /**
     * @stability stable
     */
    resetTitleAlign(): void;
    /**
     * @stability stable
     */
    get titleAlignInput(): string | undefined;
    private _titleSize?;
    /**
     * @stability stable
     */
    get titleSize(): string;
    /**
     * @stability stable
     */
    set titleSize(value: string);
    /**
     * @stability stable
     */
    resetTitleSize(): void;
    /**
     * @stability stable
     */
    get titleSizeInput(): string | undefined;
    private _customLink?;
    /**
     * @stability stable
     */
    get customLink(): DashboardWidgetGroupDefinitionWidgetServicemapDefinitionCustomLink[];
    /**
     * @stability stable
     */
    set customLink(value: DashboardWidgetGroupDefinitionWidgetServicemapDefinitionCustomLink[]);
    /**
     * @stability stable
     */
    resetCustomLink(): void;
    /**
     * @stability stable
     */
    get customLinkInput(): DashboardWidgetGroupDefinitionWidgetServicemapDefinitionCustomLink[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionCustomLink {
    /**
     * The flag for toggling context menu link visibility.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#is_hidden Dashboard#is_hidden}
     *
     * @stability stable
     */
    readonly isHidden?: boolean | cdktf.IResolvable;
    /**
     * The label for the custom link URL.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * The URL of the custom link.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#link Dashboard#link}
     *
     * @stability stable
     */
    readonly link?: string;
    /**
     * The label id that refers to a context menu link item.
     *
     * When override_label is provided, the client request omits the label field.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#override_label Dashboard#override_label}
     *
     * @stability stable
     */
    readonly overrideLabel?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionCustomLinkToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionCustomLink): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionEvent {
    /**
     * The event query to use in the widget.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#q Dashboard#q}
     *
     * @stability stable
     */
    readonly q: string;
    /**
     * The execution method for multi-value filters.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#tags_execution Dashboard#tags_execution}
     *
     * @stability stable
     */
    readonly tagsExecution?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionEventToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionEvent): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionMarker {
    /**
     * How the marker lines are displayed, options are one of {`error`, `warning`, `info`, `ok`} combined with one of {`dashed`, `solid`, `bold`}.
     *
     * Example: `error dashed`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#display_type Dashboard#display_type}
     *
     * @stability stable
     */
    readonly displayType?: string;
    /**
     * A label for the line or range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#label Dashboard#label}
     *
     * @stability stable
     */
    readonly label?: string;
    /**
     * A mathematical expression describing the marker, for example: `y > 1`, `-5 < y < 0`, `y = 19`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionMarkerToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionMarker): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryOutputReference | DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestApmQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Widget sorting methods. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQueryOutputReference | DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBy {
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * The maximum number of items in the group.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: number;
    /**
     * sort_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#sort_query Dashboard#sort_query}
     *
     * @stability stable
     */
    readonly sortQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBySortQuery;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupByToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBy): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryMultiComputeToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQuery {
    /**
     * The name of the index to query.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#index Dashboard#index}
     *
     * @stability stable
     */
    readonly index: string;
    /**
     * The search query to use.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#search_query Dashboard#search_query}
     *
     * @stability stable
     */
    readonly searchQuery?: string;
    /**
     * compute_query block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#compute_query Dashboard#compute_query}
     *
     * @stability stable
     */
    readonly computeQuery?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery;
    /**
     * group_by block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#group_by Dashboard#group_by}
     *
     * @stability stable
     */
    readonly groupBy?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBy[];
    /**
     * multi_compute block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#multi_compute Dashboard#multi_compute}
     *
     * @stability stable
     */
    readonly multiCompute?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute[];
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryOutputReference | DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQuery | undefined);
    private _index?;
    /**
     * @stability stable
     */
    get index(): string;
    /**
     * @stability stable
     */
    set index(value: string);
    /**
     * @stability stable
     */
    get indexInput(): string | undefined;
    private _searchQuery?;
    /**
     * @stability stable
     */
    get searchQuery(): string;
    /**
     * @stability stable
     */
    set searchQuery(value: string);
    /**
     * @stability stable
     */
    resetSearchQuery(): void;
    /**
     * @stability stable
     */
    get searchQueryInput(): string | undefined;
    private _computeQuery;
    /**
     * @stability stable
     */
    get computeQuery(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQueryOutputReference;
    /**
     * @stability stable
     */
    putComputeQuery(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery): void;
    /**
     * @stability stable
     */
    resetComputeQuery(): void;
    /**
     * @stability stable
     */
    get computeQueryInput(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryComputeQuery | undefined;
    private _groupBy?;
    /**
     * @stability stable
     */
    get groupBy(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBy[];
    /**
     * @stability stable
     */
    set groupBy(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBy[]);
    /**
     * @stability stable
     */
    resetGroupBy(): void;
    /**
     * @stability stable
     */
    get groupByInput(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryGroupBy[] | undefined;
    private _multiCompute?;
    /**
     * @stability stable
     */
    get multiCompute(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute[];
    /**
     * @stability stable
     */
    set multiCompute(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute[]);
    /**
     * @stability stable
     */
    resetMultiCompute(): void;
    /**
     * @stability stable
     */
    get multiComputeInput(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestAuditQueryMultiCompute[] | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaConditionalFormats {
    /**
     * The comparator to use. Valid values are `>`, `>=`, `<`, `<=`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#comparator Dashboard#comparator}
     *
     * @stability stable
     */
    readonly comparator: string;
    /**
     * The color palette to apply to the background, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_bg_color Dashboard#custom_bg_color}
     *
     * @stability stable
     */
    readonly customBgColor?: string;
    /**
     * The color palette to apply to the foreground, same values available as palette.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#custom_fg_color Dashboard#custom_fg_color}
     *
     * @stability stable
     */
    readonly customFgColor?: string;
    /**
     * Setting this to True hides values.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#hide_value Dashboard#hide_value}
     *
     * @stability stable
     */
    readonly hideValue?: boolean | cdktf.IResolvable;
    /**
     * Displays an image as the background.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#image_url Dashboard#image_url}
     *
     * @stability stable
     */
    readonly imageUrl?: string;
    /**
     * The metric from the request to correlate with this conditional format.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#metric Dashboard#metric}
     *
     * @stability stable
     */
    readonly metric?: string;
    /**
     * The color palette to apply.
     *
     * Valid values are `blue`, `custom_bg`, `custom_image`, `custom_text`, `gray_on_white`, `grey`, `green`, `orange`, `red`, `red_on_white`, `white_on_gray`, `white_on_green`, `green_on_white`, `white_on_red`, `white_on_yellow`, `yellow_on_white`, `black_on_light_yellow`, `black_on_light_green`, `black_on_light_red`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#palette Dashboard#palette}
     *
     * @stability stable
     */
    readonly palette: string;
    /**
     * Defines the displayed timeframe.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#timeframe Dashboard#timeframe}
     *
     * @stability stable
     */
    readonly timeframe?: string;
    /**
     * A value for the comparator.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#value Dashboard#value}
     *
     * @stability stable
     */
    readonly value: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaConditionalFormatsToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaConditionalFormats): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaLimit {
    /**
     * The number of results to return.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#count Dashboard#count}
     *
     * @stability stable
     */
    readonly count?: number;
    /**
     * The direction of the sort. Valid values are `asc`, `desc`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#order Dashboard#order}
     *
     * @stability stable
     */
    readonly order?: string;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaLimitToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaLimitOutputReference | DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaLimit): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaLimitOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaLimit | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaLimit | undefined);
    private _count?;
    /**
     * @stability stable
     */
    get count(): number;
    /**
     * @stability stable
     */
    set count(value: number);
    /**
     * @stability stable
     */
    resetCount(): void;
    /**
     * @stability stable
     */
    get countInput(): number | undefined;
    private _order?;
    /**
     * @stability stable
     */
    get order(): string;
    /**
     * @stability stable
     */
    set order(value: string);
    /**
     * @stability stable
     */
    resetOrder(): void;
    /**
     * @stability stable
     */
    get orderInput(): string | undefined;
}
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormula {
    /**
     * An expression alias.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#alias Dashboard#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * A list of display modes for each table cell. Valid values are `number`, `bar`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#cell_display_mode Dashboard#cell_display_mode}
     *
     * @stability stable
     */
    readonly cellDisplayMode?: string;
    /**
     * A string expression built from queries, formulas, and functions.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#formula_expression Dashboard#formula_expression}
     *
     * @stability stable
     */
    readonly formulaExpression: string;
    /**
     * conditional_formats block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#conditional_formats Dashboard#conditional_formats}
     *
     * @stability stable
     */
    readonly conditionalFormats?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaConditionalFormats[];
    /**
     * limit block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#limit Dashboard#limit}
     *
     * @stability stable
     */
    readonly limit?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaLimit;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormulaToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestFormula): any;
/**
 * @stability stable
 */
export interface DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryComputeQuery {
    /**
     * The aggregation method.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#aggregation Dashboard#aggregation}
     *
     * @stability stable
     */
    readonly aggregation: string;
    /**
     * The facet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#facet Dashboard#facet}
     *
     * @stability stable
     */
    readonly facet?: string;
    /**
     * Define the time interval in seconds.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/datadog/r/dashboard.html#interval Dashboard#interval}
     *
     * @stability stable
     */
    readonly interval?: number;
}
export declare function dashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryComputeQueryToTerraform(struct?: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryComputeQueryOutputReference | DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryComputeQuery): any;
/**
 * @stability stable
 */
export declare class DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryComputeQueryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryComputeQuery | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: DashboardWidgetGroupDefinitionWidgetTimeseriesDefinitionRequestLogQueryComputeQuery | undefined);
    private _aggregation?;
    /**
     * @stability stable
     */
    get aggregation(): string;
    /**
     * @stability stable
     */
    set aggregation(value: string);
    /**
     * @stability stable
     */
    get aggregationInput(): string | undefined;
    private _facet?;
    /**
     * @stability stable
     */
    get facet(): string;
    /**
     * @stability stable
     */
    set facet(value: string);
    /**
     * @stability stable
     */
    resetFacet(): void;
    /**
     * @stability stable
     */
    get facetInput(): string | undefined;
    private _interval?;
    /**
     * @stability stable
     */
    get interval(): number;
    /**
     * @stability stable
     */
    set interval(value: number);
    /**
     * @stability stable
     */
    resetInterval(): void;
    /**
     * @stability stable
     */
    get intervalInput(): number | undefined;
}
